


############################################################################################
############################################################################################
## Violence, anger + punitiveness in Mexico                                               ##
## GP, Young & Zeitzoff                                                                   ##
## MAIN ANALYSIS                                                                          ##
## 2021 jul                                                                               ##
############################################################################################
############################################################################################


##########
## PRELIMS
##########

rm(list=ls())

library(lubridate)
library(foreign)
library(data.table)
library(stargazer)
library(gtools)
library(interflex)
library(mediation)
library(xtable)
library(ggplot2)
library(maptools)
library(RColorBrewer)
library(rgdal)
library(car)
library(Hmisc)
library(reshape)
library(survey)
library(dotwhisker)
library(broom)
library(dplyr)
library(DirectEffects)
library(sandwich)
library(lmtest)
library(multiwayvcov)


setwd('~/Dropbox/YoungZeitzoff_Emotions/10_Analysis/03_GPYZ_RepPackage')


#####
## functions 
#####


## standardize based on total population SDs
st <- function(x) {
  (x - mean(x,na.rm=T))/sd(x,na.rm=T)
}


## stnadard error of mean
se <- function(x, na.rm=T) {
  (sd(x, na.rm=T)/sqrt(length(na.omit(x))))
}

# ## make transparent for maps
# trans <- function(someColor, alpha=100) {
#   newColor<-col2rgb(someColor)
#   apply(newColor, 2, function(curcoldata){rgb(red=curcoldata[1], green=curcoldata[2],
#                                               blue=curcoldata[3],alpha=alpha, maxColorValue=255)})
# }
# 
# ## output fxns for multimed (mediate)
# multimedest <- function(medmod, digits = 3) {
#   c(paste0(round(medmod$d.ave.lb[1],digits)),
#     paste0(round(medmod$z.ave.lb[1],digits)))
# }
# multimedci <- function(medmod, digits = 3) {
#   c(paste0("(", round(medmod$d.ave.ci[1,1],digits), ", ", round(medmod$d.ave.ci[2,1],digits), ")"),
#     paste0("(", round(medmod$z.ave.ci[1,1],digits), ", ", round(medmod$z.ave.ci[2,1],digits), ")"))
# }
# multimedprop <- function(medmod, digits = 3) {
#   c(paste0("[", round(medmod$d.ave.lb[1]/medmod$tau,digits), "]"),
#     'XX')
# }

## capitalize first letter
capwords <- function(s, strict = FALSE) {
  cap <- function(s) paste(toupper(substring(s, 1, 1)),
                           {s <- substring(s, 2); if(strict) tolower(s) else s},
                           sep = "", collapse = " " )
  sapply(strsplit(s, split = " "), cap, USE.NAMES = !is.null(names(s)))
}


#####
## read in data
#####

main <- read.csv('02_Data/03_Clean/data_main_clean.csv')

# add homicides data during implementation year (2017) and one month before the implementation (March 2017)
homds17 <- read.dta("02_Data/02_Raw/homicides2017.dta")
homdsmarch17 <- read.dta("02_Data/02_Raw/homdsmarch2017.dta")

mainhomds17 <- left_join(main, homds17, by=c("muncode"))
dat <- left_join(mainhomds17, homdsmarch17, by=c("state", "section"))
dat$lhrate1m <- log(dat$hrate1m+1)

# add state capacity data
cap <- read.dta("02_Data/02_Raw/state_capacity_muns.dta")
setnames(cap, c('inegimuncode', 'education'), c('muncode', 'educcap'))
dat <- left_join(dat, cap, by=c("muncode"))


##########
## RESEARCH DESIGN (DESCRIPTIVES)
##########


#####
## sample / response rate
#####

## replacement of PSUs

sample <- read.csv("02_Data/03_Clean/samples_clean.csv")

sample[!(sample$psu %in% dat$psu) & sample$sample==1,]
sort(table(dat$psu[dat$sample==2]))
sort(table(dat$psu[is.na(dat$sample)==T]))

table(dat$sample, useNA = 'always')

length(unique(dat$psu))


#####
## subset to only in sample
#####

dat <- subset(dat, is.na(dat$sample)==F)



#####
## FIGURE 2: ESTIMATED INCIDENCE OF SEVERE VIOLENCE BY STATE
#####

p <- melt(dat[,c('state', 'psu', 'hh_id', 'insec_extortion', 'insec_abduction', 
                 'insec_weapon', 'insec_assault', 'insec_protection')], 
          id=c('hh_id', 'psu', "state"))
p <- subset(p, as.character(p$variable)!='insec_index')
p$state <- capwords(as.character(p$state))
p$variable <- capwords(gsub("insec_", "", as.character(p$variable)))
p <- cast(p, state + psu~variable, fun.aggregate = function(x) mean(x[length(x) > 5], na.rm=T))
p <- melt(p, id = c('state', 'psu'))
setnames(p, c('state', 'value', 'variable'), c('State', 'Likelihood', 'Violence'))

pdf('03_Figures/04_SummStats/insec_state_box.pdf')
ggplot(p, aes(x = Violence, y = Likelihood)) +
  geom_boxplot(outlier.color = rgb(0,0,0,0)) +
  geom_jitter(aes(color = State), width = 0.2) +
  scale_colour_grey() +
  scale_y_continuous(breaks = seq(0,3,1), limits = c(0,3),
                     labels = c("Not at all", "A little bit", "Somewhat", "Very")) +
  theme_minimal() +
  theme(text = element_text(size=18), 
        axis.text.x = element_text(angle=45, vjust=0.95, hjust=1),
        legend.position = "bottom",
        panel.spacing = unit(0.5, "lines"))
dev.off()



#####
## TEXT P18: PROPORTION REPORTING EXTORTION IN DIRECT QUESTION
#####

table(dat$trauma_extortion)/length(na.omit(dat$trauma_extortion))
table(is.na(dat$trauma_extortion)) # little missingness on this direct q


#####
## APPENDIX FIGURE D.1: comparison of violence data
#####

vars <- c('lhrate1m', 'insec_exp_index', 'trauma_banner', 'insec_banner', 'trauma_blockade', 'insec_blockade', 
          'trauma_extortion', 'insec_extortion', 'insec_protection', 
          'insec_assault', 'insec_abduction', 'insec_weapon',
          'insec_body', 'insec_lynching', 'insec_murder')

cormat <- round(cor(dat[,vars], use = 'complete.obs'),2)
cormat[upper.tri(cormat)] <- NA

cormat <- na.omit(melt(cormat, na.rm=T))
cormat$Var1 <- car::recode(cormat$X1, "'lhrate1m'='Homicide Rate (last month)';
'insec_exp_index'='Violence Index';
                           'trauma_banner'='Seen Narco Banner (Direct)';
                           'insec_banner'='Seen Narco Banner';
                                                      'trauma_blockade'='Seen Narco Blockade (Direct)';
                           'insec_blockade'='Seen Narco Blockade';
                                                      'trauma_extortion'='Extortion (Direct)';
                           'insec_extortion'='Extortion';
                                                      'insec_protection'='Paid for Protection';
                                                      'insec_assault'='Assaulted';
                                                      'insec_abduction'='Abducted';
                                                      'insec_weapon'='Threatened with Weapon';
                           'insec_body'='Seen Body';
                           'insec_lynching'='Seen Lynching';
                           'insec_murder'='Seen Murder'", as.factor = T, 
                           levels = c('Homicide Rate (last month)', 'Violence Index', 'Seen Narco Banner (Direct)',
                                     'Seen Narco Banner', 'Seen Narco Blockade (Direct)', 
                                     'Seen Narco Blockade', 'Extortion (Direct)', 'Extortion', 
                                     'Paid for Protection', 'Assaulted', 'Abducted', 'Threatened with Weapon',
                                     'Seen Body', 'Seen Lynching', 'Seen Murder'))
cormat$Var2 <- car::recode(cormat$X2, "'lhrate1m'='Homicide Rate (last month)';
'insec_exp_index'='Violence Index';
                           'trauma_banner'='Seen Narco Banner (Direct)';
                           'insec_banner'='Seen Narco Banner';
                                                      'trauma_blockade'='Seen Narco Blockade (Direct)';
                           'insec_blockade'='Seen Narco Blockade';
                                                      'trauma_extortion'='Extortion (Direct)';
                           'insec_extortion'='Extortion';
                                                      'insec_protection'='Paid for Protection';
                                                      'insec_assault'='Assaulted';
                                                      'insec_abduction'='Abducted';
                                                      'insec_weapon'='Threatened with Weapon';
                           'insec_body'='Seen Body';
                           'insec_lynching'='Seen Lynching';
                           'insec_murder'='Seen Murder'", as.factor = T, 
                           levels = c('Homicide Rate (last month)', 'Violence Index', 'Seen Narco Banner (Direct)',
                                      'Seen Narco Banner', 'Seen Narco Blockade (Direct)', 
                                      'Seen Narco Blockade', 'Extortion (Direct)', 'Extortion', 
                                      'Paid for Protection', 'Assaulted', 'Abducted', 'Threatened with Weapon',
                                      'Seen Body', 'Seen Lynching', 'Seen Murder'))


pdf('03_Figures/04_SummStats/viol_corrs.pdf')
ggplot(data = cormat, aes(x=Var2, y=Var1, fill=value)) + 
  geom_tile(color = "white") +
  geom_text(aes(label = value), color = "black", size = 2.5) +
  theme_minimal() +
  theme(text = element_text(size=14), 
        axis.text.x = element_text(angle = 90, hjust = 1)) +
  scale_fill_gradient2(low = "blue", high = "red", mid = "white", 
                       midpoint = 0, limit = c(-1,1), space = "Lab", 
                       name="Pearson\nCorrelation") 
  coord_fixed()
dev.off()



#-------------------------------------------------------------------------------------------
# STUDY 1: CORRELATES OF VIOLENCE EXPOSURE
#-------------------------------------------------------------------------------------------

#####
## FIGURE 3: POLICY PREFS
#####

p <- melt(dat[,c('state', 'psu', 'hh_id', 'pol_auto', 'pol_armed', 'pol_narcos_rev',
                 'pol_death', 'pol_tech')], 
          id=c('hh_id', 'psu', "state"))
p$state <- capwords(as.character(p$state))
p$variable <- capwords(gsub("pol_", "", as.character(p$variable)))
p <- cast(p, value ~ variable, length, subset=is.na(value)==F, margins="grand_row")
p[1:5,2] <- p[1:5,2]/p[p$value=="(all)",2]
p[1:5,3] <- p[1:5,3]/p[p$value=="(all)",3]
p[1:5,4] <- p[1:5,4]/p[p$value=="(all)",4]
p[1:5,5] <- p[1:5,5]/p[p$value=="(all)",5]
p[1:5,6] <- p[1:5,6]/p[p$value=="(all)",6]
p <- p[p$value!="(all)",]
p <- melt(p, id = c('value'))
setnames(p, c('value', 'value.1', 'variable'), c('Response', 'Proportion', 'Policy'))
p$Response <- Recode(p$Response, "'-2'='Strongly Disagree';'-1'='Disagree';
                     '0'='Neither';'1'='Agree';'2'='Strongly Agree'", 
                      levels = c("Strongly Disagree", "Disagree", "Neither",
                                                      "Agree", "Strongly Agree"))
p$Policy <- Recode(p$Policy, "'Armed'='Support Non-Govt Armed Groups';
                   'Auto'='Support Autodefensas';
                   'Narcos_rev'='Oppose Paying Narcos';
                   'Death'='Support Death Penalty';
                   'Tech'='Prefer Lynching to Release on Technicality'",
                
                   levels = c('Support Death Penalty', 'Oppose Paying Narcos',
                              'Support Non-Govt Armed Groups',
                              'Support Autodefensas',
                              'Prefer Lynching to Release on Technicality'
                   ))

pdf('03_Figures/04_SummStats/pol_bar.pdf')
ggplot(p, aes(x = Response, y = Proportion)) +
  geom_bar(stat = 'identity', aes(fill = Response)) +
  # scale_fill_manual("Response", values = c("Strongly Disagree" = "#e84353", "Disagree" = "#ec6875",
  #                                          "Neither" = "#c0c5ce", "Agree" = "#8b9dc3", "Strongly Agree" = "#3b5998" )) +
  facet_wrap( ~ Policy, ncol = 2) +
  scale_fill_grey() +
  theme_minimal() +
  theme(text = element_text(size=15), 
        axis.text.x = element_text(angle=45, vjust=0.95, hjust=1),
        legend.position = "none",
        panel.spacing = unit(0.5, "lines"))
dev.off()



#####
## TEXT: is support for pro-vig higher in Michaocan?
#####

m1 <- lm(pol_auto ~ state - 1, data = dat, weights = w_ag)
m2 <- lm(pol_armed ~ state - 1, data = dat, weights = w_ag)
m3 <- lm(pol_tech ~ state - 1, data = dat, weights = w_ag)
m4 <- lm(pol_death ~ state - 1, data = dat, weights = w_ag)
m5 <- lm(pol_narcos_rev ~ state - 1, data = dat, weights = w_ag)

stargazer(m1, m2, m3, m4, m5)




#####
## TEXT APPENDIX P19: CORRELATION OF BLAME + PUNITIVNESS MEASURES
#####

cor(dat[,c('blame_army', 'blame_auto', 'blame_fedpol', 'blame_locpol', 'blame_narcos', 'blame_pol')], use = 'complete.obs')
cor(dat[,c('pun_army', 'pun_auto', 'pun_fedpol', 'pun_locpol', 'pun_narcos', 'pun_pol')], use = 'complete.obs')

cor(dat[,c('blame_army', 'pun_army')], use = 'complete.obs')
cor(dat[,c('blame_auto', 'pun_auto')], use = 'complete.obs')
cor(dat[,c('blame_fedpol', 'pun_fedpol')], use = 'complete.obs')
cor(dat[,c('blame_locpol', 'pun_locpol')], use = 'complete.obs')
cor(dat[,c('blame_narcos', 'pun_narcos')], use = 'complete.obs')
cor(dat[,c('blame_pol', 'pun_pol')], use = 'complete.obs')




#####
## STUDY 1 TABLES: SET SPECIFICATIONS
#####

## set specifications
spec1 <- 'insec_exp_index'
spec2 <- '+ female + education + assets_index + age + married + employed_hh'
spec3 <- '+ psu'
spec4 <- '+ secmindist_log_rev_st + secmindist_log_rev_st:insec_exp_index'
spec5 <- '+ groups.sec_st + groups.sec_st:insec_exp_index'


## set weights
dat[,'(weights)'] <- dat$w_ag


## create some vars
setnames(dat, 'homdrate.x', 'homdrate')
dat$trauma_extortion_st <- st(dat$trauma_extortion)
dat$secmindist <- rowMeans(dat[,c('polmindist', 'milmindist')], na.rm=T)
dat$secmindist <- apply(dat[,c('polmindist', 'milmindist')], 1, FUN = min)
dat$secmindist_log_st <- st(log(dat$secmindist))
dat$secmindist_log_rev_st <- st(log(max(dat$secmindist)-dat$secmindist+0.1))
dat$milmindist_log_st <- st(log(dat$milmindist))
dat$polmindist_log_st <- st(log(dat$polmindist))
dat$groups.sec_st <- st(rowMeans(dat[,c('groups.army', 'groups.police')], na.rm=T))
dat$milmindist_log_rev_st <- dat$milmindist_log_st*-1
dat$polmindist_log_rev_st <- dat$polmindist_log_st*-1



#####
## TABLE 1: emotion and attributions correlation w violence
#####

## anger

m1a <- lm(as.formula(paste0('anger_pre_index ~ ', spec1)), data = dat, weights = w_ag)
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, dat$MUNICIPIO.x))[,2]
m1b <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, dat$MUNICIPIO.x))[,2]
m1c <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$MUNICIPIO.x))[,2]
m1c$psu_no <- length(unique(m1c$model[,'psu']))
m1d <- lm(as.formula(paste0('anger_pre_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m1d$se <- coeftest(m1d, vcov = cluster.vcov(m1d, dat$MUNICIPIO.x))[,2]
m1e <- lm(as.formula(paste0('anger_pre_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m1e$se <- coeftest(m1e, vcov = cluster.vcov(m1e, dat$MUNICIPIO.x))[,2]
m1f <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m1f$se <- coeftest(m1f, vcov = cluster.vcov(m1f, dat$MUNICIPIO.x))[,2]
m1g <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m1g$se <- coeftest(m1g, vcov = cluster.vcov(m1g, dat$MUNICIPIO.x))[,2]


stargazer(m1a, m1b, m1c, m1f, m1g, m1d, m1e,
          se = list(m1a$se, m1b$se, m1c$se, m1f$se, m1g$se, m1d$se, m1e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more anger",
          label = "tab:obs_psych",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Anger', "", "", "", "", "", ""))



#####
## APPENDIX TABLES: Alternative emotions
#####

## Fear

m2a <- lm(as.formula(paste0('fear_pre_index ~ ', spec1)), data = dat, weights = w_ag)
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, dat$MUNICIPIO.x))[,2]
m2b <- lm(as.formula(paste0('fear_pre_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, dat$MUNICIPIO.x))[,2]
m2c <- lm(as.formula(paste0('fear_pre_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$MUNICIPIO.x))[,2]
m2c$psu_no <- length(unique(m2c$model[,'psu']))
m2d <- lm(as.formula(paste0('fear_pre_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m2d$se <- coeftest(m2d, vcov = cluster.vcov(m2d, dat$MUNICIPIO.x))[,2]
m2e <- lm(as.formula(paste0('fear_pre_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m2e$se <- coeftest(m2e, vcov = cluster.vcov(m2e, dat$MUNICIPIO.x))[,2]
m2f <- lm(as.formula(paste0('fear_pre_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m2f$se <- coeftest(m2f, vcov = cluster.vcov(m2f, dat$MUNICIPIO.x))[,2]
m2g <- lm(as.formula(paste0('fear_pre_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m2g$se <- coeftest(m2g, vcov = cluster.vcov(m2g, dat$MUNICIPIO.x))[,2]

stargazer(m2a, m2b, m2c, m2f, m2g, m2d, m2e,
          se = list(m2a$se, m2b$se, m2c$se, m2f$se, m2g$se, m2d$se, m2e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more fear",
          label = "tab:obs_psych_fear",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Fear', "", "", "", "", "", ""))

## Sadness

m3a <- lm(as.formula(paste0('sad_pre_index ~ ', spec1)), data = dat, weights = w_ag)
m3a$se <- coeftest(m3a, vcov = cluster.vcov(m3a, dat$MUNICIPIO.x))[,2]
m3b <- lm(as.formula(paste0('sad_pre_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m3b$se <- coeftest(m3b, vcov = cluster.vcov(m3b, dat$MUNICIPIO.x))[,2]
m3c <- lm(as.formula(paste0('sad_pre_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, dat$MUNICIPIO.x))[,2]
m3c$psu_no <- length(unique(m3c$model[,'psu']))
m3d <- lm(as.formula(paste0('sad_pre_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m3d$se <- coeftest(m3d, vcov = cluster.vcov(m3d, dat$MUNICIPIO.x))[,2]
m3e <- lm(as.formula(paste0('sad_pre_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m3e$se <- coeftest(m3e, vcov = cluster.vcov(m3e, dat$MUNICIPIO.x))[,2]
m3f <- lm(as.formula(paste0('sad_pre_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m3f$se <- coeftest(m3f, vcov = cluster.vcov(m3f, dat$MUNICIPIO.x))[,2]
m3g <- lm(as.formula(paste0('sad_pre_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m3g$se <- coeftest(m3g, vcov = cluster.vcov(m3g, dat$MUNICIPIO.x))[,2]

stargazer(m3a, m3b, m3c, m3f, m3g, m3d, m3e,
          se = list(m3a$se, m3b$se, m3c$se, m3f$se, m3g$se, m3d$se, m3e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more sadness",
          label = "tab:obs_psych_sadness",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Sadness', "", "", "", "", "", ""))

## Happiness

m4a <- lm(as.formula(paste0('happy_pre_index ~ ', spec1)), data = dat, weights = w_ag)
m4a$se <- coeftest(m4a, vcov = cluster.vcov(m4a, dat$MUNICIPIO.x))[,2]
m4b <- lm(as.formula(paste0('happy_pre_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m4b$se <- coeftest(m4b, vcov = cluster.vcov(m4b, dat$MUNICIPIO.x))[,2]
m4c <- lm(as.formula(paste0('happy_pre_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m4c$se <- coeftest(m4c, vcov = cluster.vcov(m4c, dat$MUNICIPIO.x))[,2]
m4c$psu_no <- length(unique(m4c$model[,'psu']))
m4d <- lm(as.formula(paste0('happy_pre_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m4d$se <- coeftest(m4d, vcov = cluster.vcov(m4d, dat$MUNICIPIO.x))[,2]
m4e <- lm(as.formula(paste0('happy_pre_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m4e$se <- coeftest(m4e, vcov = cluster.vcov(m4e, dat$MUNICIPIO.x))[,2]
m4f <- lm(as.formula(paste0('happy_pre_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m4f$se <- coeftest(m4f, vcov = cluster.vcov(m4f, dat$MUNICIPIO.x))[,2]
m4g <- lm(as.formula(paste0('happy_pre_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m4g$se <- coeftest(m4g, vcov = cluster.vcov(m4g, dat$MUNICIPIO.x))[,2]


stargazer(m4a, m4b, m4c, m4f, m4g, m4d, m4e,
          se = list(m4a$se, m4b$se, m4c$se, m4f$se, m4g$se, m4d$se, m4e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with no differences in happiness",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          label = "tab:obs_psych_happiness",
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Happiness', "", "", "", "", "", ""))



## check for relative magnitude of other emotion coefs vis a vis anger

lm(as.formula(paste0('fear_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']/
  lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']
lm(as.formula(paste0('sad_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']/
  lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']
lm(as.formula(paste0('happy_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']/
  lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3)), data = dat)$coefficient['insec_exp_index']



#####
## APPENDIX TABLE E.9: Blame
#####

m2a <- lm(as.formula(paste0('blame_all_st ~ ', spec1)), data = dat, weights = w_ag)
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, dat$MUNICIPIO.x))[,2]
m2b <- lm(as.formula(paste0('blame_all_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, dat$MUNICIPIO.x))[,2]
m2c <- lm(as.formula(paste0('blame_all_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$MUNICIPIO.x))[,2]
m2c$psu_no <- length(unique(m2c$model[,'psu']))
m2d <- lm(as.formula(paste0('blame_all_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m2d$se <- coeftest(m2d, vcov = cluster.vcov(m2d, dat$MUNICIPIO.x))[,2]
m2e <- lm(as.formula(paste0('blame_all_st ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m2e$se <- coeftest(m2e, vcov = cluster.vcov(m2e, dat$MUNICIPIO.x))[,2]
m2f <- lm(as.formula(paste0('blame_all_st ~ ', spec1, spec2, '+ secmindist_log_st + secmindist_log_st:insec_exp_index')), data = dat, weights = w_ag)
m2f$se <- coeftest(m2f, vcov = cluster.vcov(m2f, dat$MUNICIPIO.x))[,2]
m2g <- lm(as.formula(paste0('blame_all_st ~ ', spec1, spec2, spec3, '+ groups.sec_st + groups.sec_st:insec_exp_index')), data = dat, weights = w_ag)
m2g$se <- coeftest(m2g, vcov = cluster.vcov(m2g, dat$MUNICIPIO.x))[,2]

stargazer(m2a, m2b, m2c, m2f, m2g, m2d, m2e,
          se = list(m2a$se, m2b$se, m2c$se, m2f$se, m2g$se, m2d$se, m2e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more blame",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          label = "tab:obs_psych_blame",
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Blame', "", "", "", "", "", ""))



#####
## APPENDIX TABLE E.10: Punitiveness
#####

m3a <- lm(as.formula(paste0('pun_all_st ~ ', spec1)), data = dat, weights = w_ag)
m3a$se <- coeftest(m3a, vcov = cluster.vcov(m3a, dat$MUNICIPIO.x))[,2]
m3b <- lm(as.formula(paste0('pun_all_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m3b$se <- coeftest(m3b, vcov = cluster.vcov(m3b, dat$MUNICIPIO.x))[,2]
m3c <- lm(as.formula(paste0('pun_all_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, dat$MUNICIPIO.x))[,2]
m3c$psu_no <- length(unique(m3c$model[,'psu']))
m3d <- lm(as.formula(paste0('pun_all_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m3d$se <- coeftest(m3d, vcov = cluster.vcov(m3d, dat$MUNICIPIO.x))[,2]
m3e <- lm(as.formula(paste0('pun_all_st ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m3e$se <- coeftest(m3e, vcov = cluster.vcov(m3e, dat$MUNICIPIO.x))[,2]
m3f <- lm(as.formula(paste0('pun_all_st ~ ', spec1, spec2, '+ secmindist_log_st + secmindist_log_st:insec_exp_index')), data = dat, weights = w_ag)
m3f$se <- coeftest(m3f, vcov = cluster.vcov(m3f, dat$MUNICIPIO.x))[,2]
m3g <- lm(as.formula(paste0('pun_all_st ~ ', spec1, spec2, spec3, '+ groups.sec_st + groups.sec_st:insec_exp_index')), data = dat, weights = w_ag)
m3g$se <- coeftest(m3g, vcov = cluster.vcov(m3g, dat$MUNICIPIO.x))[,2]

stargazer(m3a, m3b, m3c, m3f, m3g, m3d, m3e,
          se = list(m3a$se, m3b$se, m3c$se, m3f$se, m3g$se, m3d$se, m3e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more punitiveness",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          label = "tab:obs_psych_blame",
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Punitiveness', "", "", "", "", "", ""))



#####
## APPENDIX FIGURE E.1: Disaggregated coefficients
#####

## E.1a: disaggregated blame

m1c <- lm(as.formula(paste0('blame_army_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$MUNICIPIO.x))[,2]
m2c <- lm(as.formula(paste0('blame_auto_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$MUNICIPIO.x))[,2]
m3c <- lm(as.formula(paste0('blame_fedpol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, dat$MUNICIPIO.x))[,2]
m4c <- lm(as.formula(paste0('blame_locpol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m4c$se <- coeftest(m4c, vcov = cluster.vcov(m4c, dat$MUNICIPIO.x))[,2]
m5c <- lm(as.formula(paste0('blame_narcos_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m5c$se <- coeftest(m5c, vcov = cluster.vcov(m5c, dat$MUNICIPIO.x))[,2]
m6c <- lm(as.formula(paste0('blame_pol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m6c$se <- coeftest(m6c, vcov = cluster.vcov(m6c, dat$MUNICIPIO.x))[,2]

coefs <- c(summary(m1c)$coef['insec_exp_index',1], summary(m2c)$coef['insec_exp_index',1],
           summary(m3c)$coef['insec_exp_index',1], summary(m4c)$coef['insec_exp_index',1],
           summary(m5c)$coef['insec_exp_index',1], summary(m6c)$coef['insec_exp_index',1])
ses <- c(m1c$se['insec_exp_index'], m2c$se['insec_exp_index'], 
         m3c$se['insec_exp_index'], m4c$se['insec_exp_index'],
         m5c$se['insec_exp_index'], m6c$se['insec_exp_index'])
p <- data.frame('Group' = c('Army', 'Autodefensas', 'Federal Police', 'Local Police',
                            'Narcos', 'Politicians'),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/01_Obs/blame_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Group, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Group, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## E.1b: Disaggregated punitiveness

m1c <- lm(as.formula(paste0('pun_army_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$MUNICIPIO.x))[,2]
m2c <- lm(as.formula(paste0('pun_auto_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$MUNICIPIO.x))[,2]
m3c <- lm(as.formula(paste0('pun_fedpol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, dat$MUNICIPIO.x))[,2]
m4c <- lm(as.formula(paste0('pun_locpol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m4c$se <- coeftest(m4c, vcov = cluster.vcov(m4c, dat$MUNICIPIO.x))[,2]
m5c <- lm(as.formula(paste0('pun_narcos_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m5c$se <- coeftest(m5c, vcov = cluster.vcov(m5c, dat$MUNICIPIO.x))[,2]
m6c <- lm(as.formula(paste0('pun_pol_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m6c$se <- coeftest(m6c, vcov = cluster.vcov(m6c, dat$MUNICIPIO.x))[,2]

coefs <- c(summary(m1c)$coef['insec_exp_index',1], summary(m2c)$coef['insec_exp_index',1],
           summary(m3c)$coef['insec_exp_index',1], summary(m4c)$coef['insec_exp_index',1],
           summary(m5c)$coef['insec_exp_index',1], summary(m6c)$coef['insec_exp_index',1])
ses <- c(m1c$se['insec_exp_index'], m2c$se['insec_exp_index'], 
         m3c$se['insec_exp_index'], m4c$se['insec_exp_index'],
         m5c$se['insec_exp_index'], m6c$se['insec_exp_index'])
p <- data.frame('Group' = c('Army', 'Autodefensas', 'Federal Police', 'Local Police',
                            'Narcos', 'Politicians'),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/01_Obs/pun_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Group, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Group, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


#####
## TABLE 2: policy pref correlations w violence
#####

## political attitudes index

m0a <- lm(as.formula(paste0('pol_index ~ ', spec1)), data = dat, weights = w_ag)
m0a$se <- coeftest(m0a, vcov = cluster.vcov(m0a, dat$MUNICIPIO.x))[,2]
m0b <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m0b$se <- coeftest(m0b, vcov = cluster.vcov(m0b, dat$MUNICIPIO.x))[,2]
m0c <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m0c$se <- coeftest(m0c, vcov = cluster.vcov(m0c, dat$MUNICIPIO.x))[,2]
m0c$psu_no <- length(unique(m0c$model[,'psu']))
m0d <- lm(as.formula(paste0('pol_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m0d$se <- coeftest(m0d, vcov = cluster.vcov(m0d, dat$MUNICIPIO.x))[,2]
m0e <- lm(as.formula(paste0('pol_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m0e$se <- coeftest(m0e, vcov = cluster.vcov(m0e, dat$MUNICIPIO.x))[,2]
m0f <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m0f$se <- coeftest(m0f, vcov = cluster.vcov(m0f, dat$MUNICIPIO.x))[,2]
m0g <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m0g$se <- coeftest(m0g, vcov = cluster.vcov(m0g, dat$MUNICIPIO.x))[,2]

stargazer(m0a, m0b, m0c, m0f, m0g, m0d, m0e, 
          se = list(m0a$se, m0b$se, m0c$se, m0f$se, m0g$se, m0d$se, m0e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base X Violence Index',
                               'Presence of State Security', 'Presence of State Security X Violence Index',
                               'Constant'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          no.space = T, keep.stat = c('n', 'rsq'),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Policy Attitudes Index'))




#####
## Appendix Table E1: Disagg policy prefs - Harsh Pun Index
#####

## Some people have suggested that one way to stop the violence is to bring back the death penalty. Do you support or oppose this proposal? 

m4a <- lm(as.formula(paste0('pol_death_st ~ ', spec1)), data = dat, weights = w_ag)
m4a$se <- coeftest(m4a, vcov = cluster.vcov(m4a, dat$MUNICIPIO.x))[,2]
m4b <- lm(as.formula(paste0('pol_death_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m4b$se <- coeftest(m4b, vcov = cluster.vcov(m4b, dat$MUNICIPIO.x))[,2]
m4c <- lm(as.formula(paste0('pol_death_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m4c$se <- coeftest(m4c, vcov = cluster.vcov(m4c, dat$MUNICIPIO.x))[,2]
m4c$psu_no <- length(unique(m4c$model[,'psu']))
m4d <- lm(as.formula(paste0('pol_death_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m4d$se <- coeftest(m4d, vcov = cluster.vcov(m4d, dat$MUNICIPIO.x))[,2]
m4e <- lm(as.formula(paste0('pol_death_st ~ ', 'trauma_extortion_st', spec2, spec3)), data = dat, weights = w_ag)
m4e$se <- coeftest(m4e, vcov = cluster.vcov(m4e, dat$MUNICIPIO.x))[,2]
m4f <- lm(as.formula(paste0('pol_death_st ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m4f$se <- coeftest(m4f, vcov = cluster.vcov(m4f, dat$MUNICIPIO.x))[,2]
m4g <- lm(as.formula(paste0('pol_death_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m4g$se <- coeftest(m4g, vcov = cluster.vcov(m4g, dat$MUNICIPIO.x))[,2]

stargazer(m4a, m4b, m4c, m4f, m4g, m4d, m4e, 
          se = list(m4a$se, m4b$se, m4c$se, m4f$se, m4g$se, m4d$se, m4e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Support Death Penalty'))


## Some people have suggested that one way to stop the violence is to pay narcos to stop killing civilians. Do you support or oppose this proposal? 

m5a <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', spec1)), data = dat, weights = w_ag)
m5a$se <- coeftest(m5a, vcov = cluster.vcov(m5a, dat$MUNICIPIO.x))[,2]
m5b <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m5b$se <- coeftest(m5b, vcov = cluster.vcov(m5b, dat$MUNICIPIO.x))[,2]
m5c <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m5c$se <- coeftest(m5c, vcov = cluster.vcov(m5c, dat$MUNICIPIO.x))[,2]
m5c$psu_no <- length(unique(m5c$model[,'psu']))
m5d <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m5d$se <- coeftest(m5d, vcov = cluster.vcov(m5d, dat$MUNICIPIO.x))[,2]
m5e <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', 'trauma_extortion_st', spec2, spec3)), data = dat, weights = w_ag)
m5e$se <- coeftest(m5e, vcov = cluster.vcov(m5e, dat$MUNICIPIO.x))[,2]
m5f <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m5f$se <- coeftest(m5f, vcov = cluster.vcov(m5f, dat$MUNICIPIO.x))[,2]
m5g <- lm(as.formula(paste0('pol_narcos_rev_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m5g$se <- coeftest(m5g, vcov = cluster.vcov(m5g, dat$MUNICIPIO.x))[,2]


stargazer(m5a, m5b, m5c, m5f, m5g, m5d, m5e, 
          se = list(m5a$se, m5b$se, m5c$se, m5f$se, m5g$se, m5d$se, m5e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Pay Narcos (Reversed)'))


#####
## Appendix Table E2: Disagg policy prefs - Pro-Vig Index
#####

## Some people believe that it is necessary to have armed groups outside of the government, because the police and army are not capable of protecting us. Do you agree or disagree with this belief?

m1a <- lm(as.formula(paste0('pol_armed_st ~ ', spec1)), data = dat, weights = w_ag)
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, dat$MUNICIPIO.x))[,2]
m1b <- lm(as.formula(paste0('pol_armed_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, dat$MUNICIPIO.x))[,2]
m1c <- lm(as.formula(paste0('pol_armed_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$MUNICIPIO.x))[,2]
m1c$psu_no <- length(unique(m1c$model[,'psu']))
m1d <- lm(as.formula(paste0('pol_armed_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m1d$se <- coeftest(m1d, vcov = cluster.vcov(m1d, dat$MUNICIPIO.x))[,2]
m1e <- lm(as.formula(paste0('pol_armed_st ~ ', 'trauma_extortion_st', spec2, spec3)), data = dat, weights = w_ag)
m1e$se <- coeftest(m1e, vcov = cluster.vcov(m1e, dat$MUNICIPIO.x))[,2]
m1f <- lm(as.formula(paste0('pol_armed_st ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m1f$se <- coeftest(m1f, vcov = cluster.vcov(m1f, dat$MUNICIPIO.x))[,2]
m1g <- lm(as.formula(paste0('pol_armed_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m1g$se <- coeftest(m1g, vcov = cluster.vcov(m1g, dat$MUNICIPIO.x))[,2]


stargazer(m1a, m1b, m1c, m1f, m1g, m1d, m1e, 
          se = list(m1a$se, m1b$se, m1c$se, m1f$se, m1g$se, m1d$se, m1e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Armed Groups Necessary'))


## Some people believe that the autodefensas are necessary to control violence in Mexico. Do you support or oppose this view?

m2a <- lm(as.formula(paste0('pol_auto_st ~ ', spec1)), data = dat, weights = w_ag)
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, dat$MUNICIPIO.x))[,2]
m2b <- lm(as.formula(paste0('pol_auto_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, dat$MUNICIPIO.x))[,2]
m2c <- lm(as.formula(paste0('pol_auto_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$MUNICIPIO.x))[,2]
m2c$psu_no <- length(unique(m2c$model[,'psu']))
m2d <- lm(as.formula(paste0('pol_auto_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m2d$se <- coeftest(m2d, vcov = cluster.vcov(m2d, dat$MUNICIPIO.x))[,2]
m2e <- lm(as.formula(paste0('pol_auto_st ~ ', 'trauma_extortion_st', spec2, spec3)), data = dat, weights = w_ag)
m2e$se <- coeftest(m2e, vcov = cluster.vcov(m2e, dat$MUNICIPIO.x))[,2]
m2f <- lm(as.formula(paste0('pol_auto_st ~ ', spec1, spec2, '+ secmindist_log_st + secmindist_log_st:insec_exp_index')), data = dat, weights = w_ag)
m2f$se <- coeftest(m2f, vcov = cluster.vcov(m2f, dat$MUNICIPIO.x))[,2]
m2g <- lm(as.formula(paste0('pol_auto_st ~ ', spec1, spec2, spec3, '+ groups.sec_st + groups.sec_st:insec_exp_index')), data = dat, weights = w_ag)
m2g$se <- coeftest(m2g, vcov = cluster.vcov(m2g, dat$MUNICIPIO.x))[,2]


stargazer(m2a, m2b, m2c, m2f, m2g, m2d, m2e, 
          se = list(m2a$se, m2b$se, m2c$se, m2f$se, m2g$se, m2d$se, m2e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Support Autodefensas'))


## Freed on a technicality or lynched in the town square ?

m6a <- lm(as.formula(paste0('pol_tech_st ~ ', spec1)), data = dat, weights = w_ag)
m6a$se <- coeftest(m6a, vcov = cluster.vcov(m6a, dat$MUNICIPIO.x))[,2]
m6b <- lm(as.formula(paste0('pol_tech_st ~ ', spec1, spec2)), data = dat, weights = w_ag)
m6b$se <- coeftest(m6b, vcov = cluster.vcov(m6b, dat$MUNICIPIO.x))[,2]
m6c <- lm(as.formula(paste0('pol_tech_st ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m6c$se <- coeftest(m6c, vcov = cluster.vcov(m6c, dat$MUNICIPIO.x))[,2]
m6c$psu_no <- length(unique(m6c$model[,'psu']))
m6d <- lm(as.formula(paste0('pol_tech_st ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m6d$se <- coeftest(m6d, vcov = cluster.vcov(m6d, dat$MUNICIPIO.x))[,2]
m6e <- lm(as.formula(paste0('pol_tech_st ~ ', 'trauma_extortion_st', spec2, spec3)), data = dat, weights = w_ag)
m6e$se <- coeftest(m6e, vcov = cluster.vcov(m6e, dat$MUNICIPIO.x))[,2]
m6f <- lm(as.formula(paste0('pol_tech_st ~ ', spec1, spec2, '+ secmindist_log_st + secmindist_log_st:insec_exp_index')), data = dat, weights = w_ag)
m6f$se <- coeftest(m6f, vcov = cluster.vcov(m6f, dat$MUNICIPIO.x))[,2]
m6g <- lm(as.formula(paste0('pol_tech_st ~ ', spec1, spec2, spec3, '+ groups.sec_st + groups.sec_st:insec_exp_index')), data = dat, weights = w_ag)
m6g$se <- coeftest(m6g, vcov = cluster.vcov(m6g, dat$MUNICIPIO.x))[,2]

stargazer(m6a, m6b, m6c, m6f, m6g, m6d, m6e, 
          se = list(m6a$se, m6b$se, m6c$se, m6f$se, m6g$se, m6d$se, m6e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Violence Index',
                               'Presence of State Security', 'Presence of State Security $\\times$ Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Killed vs. released on a technicality'))



#####
## Presentation Figure: Substantive interpretation
#####

## pro-vigilantes

dat$insec_exp_index_bin <- ifelse(dat$insec_exp_index >= 0, 1, 0)
dat$pol_armed_bin <- ifelse(dat$pol_armed > 0, 1, 0)
dat$pol_auto_bin <- ifelse(dat$pol_auto > 0, 1, 0)
dat$pol_tech_bin <- ifelse(dat$pol_tech > 0, 1, 0)

tab <- data.table('pct.support' = c(length(dat$pol_armed_bin[dat$pol_armed_bin==1 & dat$insec_exp_index_bin==0])/
                                      length(dat$pol_armed_bin[dat$insec_exp_index_bin==0]),
                                    length(dat$pol_armed_bin[dat$pol_armed_bin==1 & dat$insec_exp_index_bin==1])/
                                      length(dat$pol_armed_bin[dat$insec_exp_index_bin==1]),
                                    length(dat$pol_auto_bin[dat$pol_auto_bin==1 & dat$insec_exp_index_bin==0])/
                                      length(dat$pol_auto_bin[dat$insec_exp_index_bin==0]),
                                    length(dat$pol_auto_bin[dat$pol_auto_bin==1 & dat$insec_exp_index_bin==1])/
                                      length(dat$pol_auto_bin[dat$insec_exp_index_bin==1]),
                                    length(dat$pol_tech_bin[dat$pol_tech_bin==1 & dat$insec_exp_index_bin==0])/
                                      length(dat$pol_tech_bin[dat$insec_exp_index_bin==0]),
                                    length(dat$pol_tech_bin[dat$pol_tech_bin==1 & dat$insec_exp_index_bin==1])/
                                      length(dat$pol_tech_bin[dat$insec_exp_index_bin==1])),
                  'Violence' = rep(c('Low', 'High'), 3))
tab$var <- c(rep('Armed
Groups',2), rep('Autodefensas',2), rep('Lynching', 2))
tab$Violence <- factor(tab$Violence, levels = c("Low", "High"))

pdf('03_Figures/01_Obs/pct_provig.pdf')
ggplot(tab, aes(var, pct.support, fill = Violence)) +
  geom_bar(stat = 'identity', position = "dodge") +
  theme_minimal() +
  theme(text = element_text(size=30), 
        axis.text.x = element_text(angle=0, vjust=0.95),
        legend.position = "bottom") +
  scale_y_continuous(labels = scales::percent, limit = c(0,0.5)) +
  ylab("Percent Support") + xlab("Sub-Indicator") 
dev.off()


## harsh punishments

dat$pol_death_bin <- ifelse(dat$pol_death > 0, 1, 0)
dat$pol_narcos_bin <- ifelse(dat$pol_narcos_rev > 0, 1, 0)

tab <- data.table('pct.support' = c(length(dat$pol_death_bin[dat$pol_death_bin==1 & dat$insec_exp_index_bin==0])/
                                      length(dat$pol_death_bin[dat$insec_exp_index_bin==0]),
                                    length(dat$pol_death_bin[dat$pol_death_bin==1 & dat$insec_exp_index_bin==1])/
                                      length(dat$pol_death_bin[dat$insec_exp_index_bin==1]),
                                    length(dat$pol_narcos_bin[dat$pol_narcos_bin==1 & dat$insec_exp_index_bin==0])/
                                      length(dat$pol_narcos_bin[dat$insec_exp_index_bin==0]),
                                    length(dat$pol_narcos_bin[dat$pol_narcos_bin==1 & dat$insec_exp_index_bin==1])/
                                      length(dat$pol_narcos_bin[dat$insec_exp_index_bin==1])),
                  'Violence' = rep(c('Low', 'High'), 2))
tab$var <- c(rep('Death
Penalty',2), rep('Pay Narcos
(Oppose)',2))
tab$Violence <- factor(tab$Violence, levels = c("Low", "High"))

pdf('03_Figures/01_Obs/pct_harsh.pdf')
ggplot(tab, aes(var, pct.support, fill = Violence)) +
  geom_bar(stat = 'identity', position = "dodge") +
  theme_minimal() +
  theme(text = element_text(size=30), 
        axis.text.x = element_text(angle=0, vjust=0.95),
        legend.position = "bottom") +
  scale_y_continuous(labels = scales::percent, limit = c(0,0.9)) +
  ylab("Percent Support") + xlab("Sub-Indicator")
dev.off()



#####
## Appendix E.3: interaction w trust in the state
#####

## set specifications
spec1 <- 'insec_exp_index'
spec2 <- '+ female + education + assets_index + age + married + employed_hh'
spec3 <- '+ psu'
spec4 <- '+ trust_state_idx + trust_state_idx:insec_exp_index'
spec5 <- '+ opin_state_all + opin_state_all:insec_exp_index'

## set weights
dat[,'(weights)'] <- dat$w_ag



## anger

m1a <- lm(as.formula(paste0('anger_pre_index ~ ', spec1)), data = dat, weights = w_ag)
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, dat$MUNICIPIO.x))[,2]
m1b <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, dat$MUNICIPIO.x))[,2]
m1c <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$MUNICIPIO.x))[,2]
m1c$psu_no <- length(unique(m1c$model[,'psu']))
m1d <- lm(as.formula(paste0('anger_pre_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m1d$se <- coeftest(m1d, vcov = cluster.vcov(m1d, dat$MUNICIPIO.x))[,2]
m1e <- lm(as.formula(paste0('anger_pre_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m1e$se <- coeftest(m1e, vcov = cluster.vcov(m1e, dat$MUNICIPIO.x))[,2]
m1f <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m1f$se <- coeftest(m1f, vcov = cluster.vcov(m1f, dat$MUNICIPIO.x))[,2]
m1g <- lm(as.formula(paste0('anger_pre_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m1g$se <- coeftest(m1g, vcov = cluster.vcov(m1g, dat$MUNICIPIO.x))[,2]


stargazer(m1a, m1b, m1c, m1f, m1g, m1d, m1e,
          se = list(m1a$se, m1b$se, m1c$se, m1f$se, m1g$se, m1d$se, m1e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married',
                   'employed', 'trust_state_idx', 'opin_state_all', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Trust State Index', 'Trust State Index X Violence Index',
                               'State Legitimacy Index', 'State Legitimacy Index X Violence Index',
                               'Constant'),
          title = "Exposure to violence is associated with more anger",
          label = "tab:obs_psych",
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Anger', "", "", "", "", "", ""))


## political attitudes index

m0a <- lm(as.formula(paste0('pol_index ~ ', spec1)), data = dat, weights = w_ag)
m0a$se <- coeftest(m0a, vcov = cluster.vcov(m0a, dat$MUNICIPIO.x))[,2]
m0b <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2)), data = dat, weights = w_ag)
m0b$se <- coeftest(m0b, vcov = cluster.vcov(m0b, dat$MUNICIPIO.x))[,2]
m0c <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m0c$se <- coeftest(m0c, vcov = cluster.vcov(m0c, dat$MUNICIPIO.x))[,2]
m0c$psu_no <- length(unique(m0c$model[,'psu']))
m0d <- lm(as.formula(paste0('pol_index ~ ', 'lhrate1m', spec2)), data = dat, weights = w_ag)
m0d$se <- coeftest(m0d, vcov = cluster.vcov(m0d, dat$MUNICIPIO.x))[,2]
m0e <- lm(as.formula(paste0('pol_index ~ ', 'trauma_extortion', spec2, spec3)), data = dat, weights = w_ag)
m0e$se <- coeftest(m0e, vcov = cluster.vcov(m0e, dat$MUNICIPIO.x))[,2]
m0f <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec4)), data = dat, weights = w_ag)
m0f$se <- coeftest(m0f, vcov = cluster.vcov(m0f, dat$MUNICIPIO.x))[,2]
m0g <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = w_ag)
m0g$se <- coeftest(m0g, vcov = cluster.vcov(m0g, dat$MUNICIPIO.x))[,2]

stargazer(m0a, m0b, m0c, m0f, m0g, m0d, m0e, 
          se = list(m0a$se, m0b$se, m0c$se, m0f$se, m0g$se, m0d$se, m0e$se),
          keep = c('insec', 'lhrate1m', 'trauma', 'female', 'educ', 'assets', 'age', 'married', 
                   'employed', 'trust_state', 'opin_state', 'Constant'),
          covariate.labels = c("Violence Index", 'Homicide Rate', 'Extortion - Direct',
                               "Female", 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Trust State Index', 'Trust State Index X Violence Index',
                               'State Legitimacy Index', 'State Legitimacy Index X Violence Index',
                               'Constant'),
          no.space = T, keep.stat = c('n', 'rsq'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          digits = 2,
          add.lines = list(c("PSU FEs", "", "", "\\checkmark", "","\\checkmark", "","\\checkmark")),
          dep.var.labels = c('Policy Attitudes Index'))




#####
## APPENDIX H: MEDIATION ANALYSIS
#####

## Acharya Blackwell Sen DirectEffect

form_main <- pol_index ~ insec_exp_index + female + education + 
  education + assets_index + age + married + employed_hh + psu |
  fear_pre_index + sad_pre_index + happy_pre_index | anger_pre_index
direct <- sequential_g(form_main, data = dat, weights = w_ag)
summary(direct)

sens <- cdesens(direct, var = "insec_exp_index")

pdf('03_Figures/01_Obs/DirectEffect_Sens.pdf')
plot(sens)
dev.off()

  ## main estimate for plot

spec1 <- 'insec_exp_index'
spec2 <- '+ female + education + assets_index + age + married + employed_hh'
spec3 <- '+ psu'

m0c <- lm(as.formula(paste0('pol_index ~ ', spec1, spec2, spec3)), data = dat, weights = w_ag)
m0c$se <- coeftest(m0c, vcov = cluster.vcov(m0c, dat$MUNICIPIO.x))[,2]

min(sens$rho[sens$acde > m0c$coefficients['insec_exp_index']])

tab <- data.frame('estimand' = c('ols', 'acde'),
                  'estimate' = c(m0c$coefficients['insec_exp_index'],
                    direct$coefficients['insec_exp_index']),
                  'ses' = c(m0c$se['insec_exp_index'],
                            summary(direct)$coefficients['insec_exp_index','Std. Err.']))
tab$up95 <- tab$estimate + 1.96*tab$ses
tab$lo95 <- tab$estimate - 1.96*tab$ses
tab$estimand <- ordered(tab$estimand, levels = c('ols', 'acde'))

pdf("03_Figures/01_Obs/DirectEffect_Anger.pdf")
ggplot(tab, aes(x = estimand)) +
  geom_point(aes(y = estimate)) +
  geom_errorbar(aes(ymin = lo95, ymax = up95),
                lwd = 1, width = 0.25) +
  geom_hline(aes(yintercept = 0), lty = 2) +
  theme_minimal() +
  theme(text = element_text(size = 28)) +
  scale_x_discrete(name = "", breaks = c('ols', 'acde'), labels = c("Total Effect", "ACDE")) +
  ylab("Estimated Coefficient")
dev.off()

tab$estimate[tab$estimand=='acde']/tab$estimate[tab$estimand=='ols']




##########
## Study 2: Moral outrage scenarios
##########

#####
## define specifications + make stacked data
#####

## stacked data

dat$sub_id <- seq(1, dim(dat)[1], 1)
t1 <- subset(dat, select = c('sub_id', 'psu', 'w_ag', '(weights)', 'treat_rage_child', 'female', 'education', 'assets_index', 
                             'age', 'married', 'employed_hh', 'insec_exp_index', 'secmindist_log_rev_st', 'groups.sec_st',
                             'veng_index', 'rage_child_anger_st', 'rage_child_fear_st',
                             'rage_child_prefB', 'rage_child_prevB', 'rage_child_justB'))
setnames(t1, c('treat_rage_child', 'rage_child_anger_st', 'rage_child_fear_st',
               'rage_child_prefB', 'rage_child_prevB', 'rage_child_justB'),
         c('treat_rage', 'rage_anger_st', 'rage_fear_st',
           'rage_prefB', 'rage_prevB', 'rage_justB'))
t1$scen <- 'child'
t2 <- subset(dat, select = c('sub_id', 'psu', 'w_ag', '(weights)', 'treat_rage_graft', 'female', 'education', 'assets_index', 
                             'age', 'married', 'employed_hh', 'insec_exp_index', 'secmindist_log_rev_st','groups.sec_st',
                             'veng_index', 'rage_graft_anger_st', 'rage_graft_fear_st',
                             'rage_graft_prefB', 'rage_graft_prevB', 'rage_graft_justB'))
setnames(t2, c('treat_rage_graft', 'rage_graft_anger_st', 'rage_graft_fear_st',
               'rage_graft_prefB', 'rage_graft_prevB', 'rage_graft_justB'),
         c('treat_rage', 'rage_anger_st', 'rage_fear_st',
           'rage_prefB', 'rage_prevB', 'rage_justB'))
t2$scen <- 'graft'
t3 <- subset(dat, select = c('sub_id', 'psu', 'w_ag', '(weights)', 'treat_rage_decap', 'female', 'education', 'assets_index', 
                             'age', 'married', 'employed_hh', 'insec_exp_index', 'secmindist_log_rev_st', 'groups.sec_st',
                             'veng_index', 'rage_decap_anger_st', 'rage_decap_fear_st',
                             'rage_decap_prefB', 'rage_decap_prevB', 'rage_decap_justB'))
setnames(t3, c('treat_rage_decap', 'rage_decap_anger_st', 'rage_decap_fear_st',
               'rage_decap_prefB', 'rage_decap_prevB', 'rage_decap_justB'),
         c('treat_rage', 'rage_anger_st', 'rage_fear_st',
           'rage_prefB', 'rage_prevB', 'rage_justB'))
t3$scen <- 'decap'

mini <- smartbind(t1, t2, t3)
mini$psu <- as.factor(mini$psu)


## specifications 

spec1 <- 'treat_rage'
spec2 <- '+ female + insec_exp_index + education + assets_index + age + married + employed_hh'
spec4 <- '+ secmindist_log_rev_st + secmindist_log_rev_st:treat_rage'
spec5 <- '+ groups.sec_st + groups.sec_st:treat_rage'


#####
## FIGURE 4: Effect of outrage scenarios on emotions by scenario (manip check)
#####

dat$treat_rage <- dat$treat_rage_child
m1a <- lm(as.formula(paste0('rage_child_anger_st ~ ', spec1)), data = dat, weights = dat$w_ag)
m1b <- lm(as.formula(paste0('rage_child_fear_st ~ ', spec1)), data = dat, weights = dat$w_ag)

dat$treat_rage <- dat$treat_rage_graft
m2a <- lm(as.formula(paste0('rage_graft_anger_st ~ ', spec1)), data = dat, weights = dat$w_ag)
m2b <- lm(as.formula(paste0('rage_graft_fear_st ~ ', spec1)), data = dat, weights = dat$w_ag)

dat$treat_rage <- dat$treat_rage_decap
m3a <- lm(as.formula(paste0('rage_decap_anger_st ~ ', spec1)), data = dat, weights = dat$w_ag)
m3b <- lm(as.formula(paste0('rage_decap_fear_st ~ ', spec1)), data = dat, weights = dat$w_ag)


## coef plot

coefs <- c(summary(m1a)$coef['treat_rage',1], summary(m1b)$coef['treat_rage',1],
           summary(m2a)$coef['treat_rage',1], summary(m2b)$coef['treat_rage',1],
           summary(m3a)$coef['treat_rage',1], summary(m3b)$coef['treat_rage',1])
ses <- c(summary(m1a)$coef['treat_rage',2], summary(m1a)$coef['treat_rage',2],
         summary(m2a)$coef['treat_rage',2], summary(m2a)$coef['treat_rage',2],
         summary(m3a)$coef['treat_rage',2], summary(m3a)$coef['treat_rage',2])
plotdat <- data.frame('Emotion' = rep(c("Anger", 'Fear'),3), coefs, ses, 
                      'x' = seq(1,6,1),
                      'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/02_Outrage/manip_check_disagg.pdf')
ggplot(plotdat, aes(colour = Emotion)) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  scale_colour_grey() +
  geom_errorbar(aes(x = x, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = x, y = coefs), 
             position = position_dodge(width=1/2), size = 3) +
  theme_minimal() +
  theme(text = element_text(size = 22)) +
  scale_x_continuous(name ="\n Outrage Scenarios", breaks = c(1.5, 3.5, 5.5),
                     labels=c("Abusing
Children","Stealing 
from Disabled","Decapitation")) +
  scale_y_continuous(name = 'Standardized Treatment Effect \n') 
dev.off()


#####
## FIGURE 5: Effect of outrage scenarios on preferences for harsh, vigilante solution
#####

m1a <- lm(as.formula(paste0('rage_prefB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, mini$sub_id[mini$scen!='decap']))[,2]
m1b <- lm(as.formula(paste0('rage_prefB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, mini$sub_id[mini$scen!='decap']))[,2]
m1c <- lm(as.formula(paste0('rage_prefB ~ ', spec1, spec2, spec4)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, mini$sub_id[mini$scen!='decap']))[,2]
m1d <- lm(as.formula(paste0('rage_prefB ~ ', spec1, spec2, spec5)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m1d$se <- coeftest(m1d, vcov = cluster.vcov(m1d, mini$sub_id[mini$scen!='decap']))[,2]

m2a <- lm(as.formula(paste0('rage_justB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, mini$sub_id[mini$scen!='decap']))[,2]
m2b <- lm(as.formula(paste0('rage_justB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, mini$sub_id[mini$scen!='decap']))[,2]
m2c <- lm(as.formula(paste0('rage_justB ~ ', spec1, spec2, spec4)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, mini$sub_id[mini$scen!='decap']))[,2]
m2d <- lm(as.formula(paste0('rage_justB ~ ', spec1, spec2, spec5)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m2d$se <- coeftest(m2d, vcov = cluster.vcov(m2d, mini$sub_id[mini$scen!='decap']))[,2]

m3a <- lm(as.formula(paste0('rage_prevB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m3a$se <- coeftest(m3a, vcov = cluster.vcov(m3a, mini$sub_id[mini$scen!='decap']))[,2]
m3b <- lm(as.formula(paste0('rage_prevB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m3b$se <- coeftest(m3b, vcov = cluster.vcov(m3b, mini$sub_id[mini$scen!='decap']))[,2]
m3c <- lm(as.formula(paste0('rage_prevB ~ ', spec1, spec2, spec4)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, mini$sub_id[mini$scen!='decap']))[,2]
m3d <- lm(as.formula(paste0('rage_prevB ~ ', spec1, spec2, spec5)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m3d$se <- coeftest(m3d, vcov = cluster.vcov(m3d, mini$sub_id[mini$scen!='decap']))[,2]


## coefficient plot

coefs <- c(summary(m1b)$coef['treat_rage',1], summary(m2b)$coef['treat_rage',1], summary(m3b)$coef['treat_rage',1])
ses <- c(summary(m1b)$coef['treat_rage',2], summary(m2b)$coef['treat_rage',2], summary(m3b)$coef['treat_rage',2])
plotdat <- data.frame('Outcome' = c("Preferred", 'More Just', 'More Effective'), coefs, ses, 
                      'x' = seq(1,3,1),
                      'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)
plotdat$Outcome <- factor(plotdat$Outcome, levels = c("Preferred", "More Just", "More Effective"))


pdf('03_Figures/02_Outrage/Study2_Prefs.pdf')
ggplot(plotdat, aes(colour = Outcome)) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = x, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.5) +
  geom_point(aes(x = x, y = coefs), 
             position = position_dodge(width=1/2), size = 3) +
  theme_minimal() +
  scale_colour_grey() +
  theme(text = element_text(size = 21),
        axis.title.x=element_blank(),
        axis.text.x=element_blank()) +
  scale_y_continuous(name = 'Average Treatment Effect')  
dev.off()



#####
## APPENDIX TABLE F1: Balance tests
#####

vars = c('age', 'female', 'married', 'kids', 'employed_hh', 'education', 
         'home_owner', 'table_assets.fridge', 'table_assets.washing', 
         'table_assets.cell', 'table_assets.smartphone', 'table_assets.computer',
         'trauma_armed', 'trauma_extortion', 'trauma_confined',
         'fear_pre', 'nervous_pre', 'anger_pre', 'indignant_pre',
         'happy_pre', 'cheerful_pre', 'sad_pre', 'dejected_pre',
         'mich', 'coli', 'jali', 'naya')
treats <- c('treat_rage_child', 'treat_rage_graft', 'treat_rage_decap')
coefs = data.frame('m1T' = rep(NA, length(vars)), 
                   'm1C' = rep(NA, length(vars)), 
                   'p1' = rep(NA,length(vars)), 
                   'm2T' = rep(NA, length(vars)), 
                   'm2C' = rep(NA, length(vars)), 
                   'p2' = rep(NA,length(vars)), 
                   'm3T' = rep(NA, length(vars)), 
                   'm3C' = rep(NA, length(vars)), 
                   'p3' = rep(NA,length(vars)), 
                   'N' = rep(NA, length(vars)))

## unweighted
for (v in 1:length(vars)){
  for (t in 1:length(treats)){
    coefs[v,paste0('m',t,'T')] <- mean(dat[dat[,treats[t]]==1,vars[v]], na.rm=T)
    coefs[v,paste0('m',t,'C')] <- mean(dat[dat[,treats[t]]==0,vars[v]], na.rm=T)
    coefs[v,paste0('p',t)] <- t.test(dat[dat[,treats[t]]==1,vars[v]], dat[dat[,treats[t]]==0,vars[v]])$p.value
  }
  n <- length(na.omit(dat[,vars[v]]))
  coefs[v,'N'] <- n
}

rownames(coefs) = vars
xtable(coefs)




#####
## APPENDIX TABLE F.3: Logit results
#####

m1a <- glm(as.formula(paste0('rage_prefB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, mini$sub_id[mini$scen!='decap']))[,2]
m1b <- glm(as.formula(paste0('rage_prefB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, mini$sub_id[mini$scen!='decap']))[,2]

m2a <- glm(as.formula(paste0('rage_justB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, mini$sub_id[mini$scen!='decap']))[,2]
m2b <- glm(as.formula(paste0('rage_justB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, mini$sub_id[mini$scen!='decap']))[,2]

m3a <- glm(as.formula(paste0('rage_prevB ~ ', spec1)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m3a$se <- coeftest(m3a, vcov = cluster.vcov(m3a, mini$sub_id[mini$scen!='decap']))[,2]
m3b <- glm(as.formula(paste0('rage_prevB ~ ', spec1, spec2)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'],
          family = 'binomial')
m3b$se <- coeftest(m3b, vcov = cluster.vcov(m3b, mini$sub_id[mini$scen!='decap']))[,2]

stargazer(m1a, m1b, m2a, m2b, m3a, m3b, 
          se = list(m1a$se, m1b$se, m2a$se, m2b$se, m3a$se, m3b$se),
          keep = c('rage', 'insec', 'female', 'educ', 'assets', 'age', 'married', 'employed', 'Constant'),
          covariate.labels = c("Outrage Treatment", "Female", 'Violence Index', 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed', 'Constant'),
          title = "Effect of outrage scenarios on preferences over and perceptions of harsh, vigilante punishments",
          label = "tab:outrage_outs",
          no.space = T, 
          # keep.stat = c('n', 'rsq'), 
          digits = 2,
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          add.lines = list(c("PSU FEs", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Vigilante Preferred', "", 'Vigilante More Just', "", 'Vigilante More Effective', ""),
          notes = c("$^{\\dagger}$p$<$0.1; $^{*}$p$<$0.05; $^{**}$p$<$0.01",
                    "Standard errors clustered by respondent in parentheses.",
                    "\\parbox{1\\linewidth}{Coefficients are estimated using OLS. Outrage Treatment is a dummy variable that takes a value of 1 if the respondent was randomly assigned to the outrageous version of the crime scenario. Controls include gender, education, age, an assets index, marital status, and employment status of the household head"), 
          notes.append = F)




#####
## APPENDIX TABLE F.4: Interactions w state capacity
#####


stargazer(m1a, m1b, m1c, m1d, m2a, m2b, m2c, m2d, m3a, m3b, m3c, m3d,
          se = list(m1a$se, m1b$se, m1c$se, m1d$se, m2a$se, m2b$se, m2c$se, m2d$se, m3a$se, m3b$se, m3c$se, m3d$se),
          keep = c('rage', 'insec', 'female', 'educ', 'assets', 'age', 'married', 'employed',
                   'secmindist', 'groups.sec', 'Constant'),
          covariate.labels = c("Outrage Treatment", "Female", 'Violence Index', 'Education',
                               'Assets Index', 'Age', 'Married', 'Employed',
                               'Proximity to Security Base', 'Prox. to Security Base $\\times$ Outrage Treatment',
                               'Proximity to Security Base', 'Presence of State Security $\\times$ Outrage Treatment',
                               'Constant'),
          title = "Effect of outrage scenarios on preferences over and perceptions of harsh, vigilante punishments",
          label = "tab:outrage_outs_interactions",
          no.space = T, keep.stat = c('n', 'rsq'), 
          digits = 2,
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          add.lines = list(c("PSU FEs", "", "\\checkmark", "", "\\checkmark", "", "\\checkmark")),
          dep.var.labels = c('Vigilante Preferred', "", 'Vigilante More Just', "", 'Vigilante More Effective', ""),
          notes = c("$^{*}$p$<$0.1; $^{**}$p$<$0.05; $^{***}$p$<$0.01",
                    "Standard errors clustered by respondent in parentheses.",
                    "\\parbox{1\\linewidth}{Coefficients are estimated using OLS. Outrage Treatment is a dummy variable that takes a value of 1 if the respondent was randomly assigned to the outrageous version of the crime scenario. Controls include gender, education, age, an assets index, marital status, and employment status of the household head"), 
          notes.append = F)



#####
## APPENDIX FIGURE F.2: Disaggregated substantive outcomes
#####

dat$treat_rage <- dat$treat_rage_child
m1a <- lm(as.formula(paste0('rage_child_prefB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, dat$sub_id))[,2]
m1b <- lm(as.formula(paste0('rage_child_justB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, dat$sub_id))[,2]
m1c <- lm(as.formula(paste0('rage_child_prevB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m1c$se <- coeftest(m1c, vcov = cluster.vcov(m1c, dat$sub_id))[,2]

dat$treat_rage <- dat$treat_rage_graft
m2a <- lm(as.formula(paste0('rage_graft_prefB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, dat$sub_id))[,2]
m2b <- lm(as.formula(paste0('rage_graft_justB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, dat$sub_id))[,2]
m2c <- lm(as.formula(paste0('rage_graft_prevB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m2c$se <- coeftest(m2c, vcov = cluster.vcov(m2c, dat$sub_id))[,2]

dat$treat_rage <- dat$treat_rage_decap
m3a <- lm(as.formula(paste0('rage_decap_prefB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m3a$se <- coeftest(m3a, vcov = cluster.vcov(m3a, dat$sub_id))[,2]
m3b <- lm(as.formula(paste0('rage_decap_justB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m3b$se <- coeftest(m3b, vcov = cluster.vcov(m3b, dat$sub_id))[,2]
m3c <- lm(as.formula(paste0('rage_decap_prevB ~ ', spec1, spec2)), data = dat, weights = dat$w_ag)
m3c$se <- coeftest(m3c, vcov = cluster.vcov(m3c, dat$sub_id))[,2]

coefs <- c(summary(m1a)$coef['treat_rage',1], summary(m1b)$coef['treat_rage',1], summary(m1c)$coef['treat_rage',1],
           summary(m2a)$coef['treat_rage',1], summary(m2b)$coef['treat_rage',1], summary(m2c)$coef['treat_rage',1],
           summary(m3a)$coef['treat_rage',1], summary(m3b)$coef['treat_rage',1], summary(m3c)$coef['treat_rage',1])
ses <- c(m1a$se['treat_rage'], m1b$se['treat_rage'], m1c$se['treat_rage'],
         m2a$se['treat_rage'], m2b$se['treat_rage'], m2c$se['treat_rage'],
         m3a$se['treat_rage'], m3b$se['treat_rage'], m3c$se['treat_rage'])
plotdat <- data.frame('Outcome' = rep(c("Preferred", 'More Just', 'More Effective'),3), coefs, ses, 
                      'x' = seq(1,9,1),
                      'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)
plotdat$Outcome <- factor(plotdat$Outcome, levels = c("Preferred", "More Just", "More Effective"))


pdf('03_Figures/02_Outrage/outs_disagg.pdf')
ggplot(plotdat, aes(colour = Outcome)) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = x, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.5) +
  geom_point(aes(x = x, y = coefs), 
             position = position_dodge(width=1/2), size = 3) +
  theme_minimal() +
  theme(text = element_text(size = 21)) +
  scale_x_continuous(name ="Scenario", breaks = c(2, 5, 8),
                     labels=c("Abusing
Children","Stealing
from Disabled","Decapitation")) +
  scale_y_continuous(name = 'Standardized Treatment Effect')  
dev.off()




#####
## APPENDIX H: MEDIATION ANALYSIS
#####

## Acharya Blackwell Sen DirectEffect

form_main <- rage_prefB ~ treat_rage + female + insec_exp_index + education + 
  education + assets_index + age + married + employed_hh + psu |
  rage_fear_st | rage_anger_st
direct <- sequential_g(form_main, data = mini[mini$scen %in% c('child', 'graft'),], 
                       weights = w_ag)
summary(direct)

sens <- cdesens(direct, var = "treat_rage")

pdf('03_Figures/02_Outrage/DirectEffect_Sens.pdf')
plot(sens)
dev.off()


## main estimate for plot 

spec1 <- 'treat_rage'
spec2 <- '+ female + insec_exp_index + education + assets_index + age + married + employed_hh'
spec25 <- ' + psu'

m1b <- lm(as.formula(paste0('rage_prefB ~ ', spec1, spec2, spec25)), data = mini[mini$scen!='decap',],
          weights = mini$w_ag[mini$scen!='decap'])
m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, mini$sub_id[mini$scen!='decap']))[,2]


tab <- data.frame('estimand' = c('ols', 'acde'),
                  'estimate' = c(m1b$coefficients['treat_rage'],
                                 direct$coefficients['treat_rage']),
                  'ses' = c(m1b$se['treat_rage'],
                            summary(direct)$coefficients['treat_rage','Std. Err.']))
tab$up95 <- tab$estimate + 1.96*tab$ses
tab$lo95 <- tab$estimate - 1.96*tab$ses
tab$estimand <- ordered(tab$estimand, levels = c('ols', 'acde'))

pdf("03_Figures/02_Outrage/DirectEffect_Anger.pdf")
ggplot(tab, aes(x = estimand)) +
  geom_point(aes(y = estimate)) +
  geom_errorbar(aes(ymin = lo95, ymax = up95),
                lwd = 1, width = 0.25) +
  geom_hline(aes(yintercept = 0), lty = 2) +
  theme_minimal() +
  theme(text = element_text(size = 28)) +
  scale_x_discrete(name = "", breaks = c('ols', 'acde'), labels = c("Total Effect", "ACDE")) +
  ylab("Estimated Coefficient")
dev.off()

tab$estimate[tab$estimand=='acde']/tab$estimate[tab$estimand=='ols']


## check for ceiling effects

prop.table(table(dat$rage_child_anger))
prop.table(table(dat$rage_child_anger, dat$treat_rage_child), margin = 2)
prop.table(table(dat$rage_graft_anger))
prop.table(table(dat$rage_graft_anger, dat$treat_rage_graft), margin = 2)



##########
## Study 3: Conjoint
##########


#####
## specifications
#####

spec1 <- 'scen1_vic_inno + scen1_vio_sev + per1_e'
spec2 <- '+ insec_exp_index + female + education + assets_index + age + married + employed_hh'
spec25 <- ' + psu'
spec3 <- '+ scen1_vic_inno:scen1_vio_sev'
spec4 <- '+ insec_exp_index + insec_exp_index:scen1_vic_inno + insec_exp_index:scen1_vio_sev +
            veng_index + veng_index:scen1_vic_inno + veng_index:scen1_vio_sev'
spec5 <- '+ secmindist_log_rev_st + secmindist_log_rev_st:scen1_vic_inno + secmindist_log_rev_st:scen1_vio_sev'
spec6 <- '+ groups.sec_st + groups.sec_st:scen1_vic_inno + groups.sec_st:scen1_vio_sev'

spec1d <- 'vic1_e + vio1_e + per1_e'
spec3d <- '+ vic1_e:vio1_e'


#####
## APPENDIX TABLE G1: Calculate scenario weights
#####

w1a <- lm(scen1_here ~ vic1_e + vio1_e + per1_e + 
            vic1_e:vio1_e + vic1_e:per1_e + vio1_e:per1_e - 1, data = dat, weights = dat$w_ag)
dat$scen1_here_pred <- predict(w1a, dat)

stargazer(w1a, no.space = T, keep.stat = c('n', 'rsq'))



#####
## APPENDIX FIGURE G1: histogram of weights 
#####

pdf("03_Figures/03_Conjoint/scen_weights.pdf")
hist(dat$scen1_here_pred, freq = T, main = "", xlab = "Scenario weight", col = 'grey')
dev.off()



#####
## FIGURE 6: Conjoint outcomes
#####

## EMOTIONS

dat$per1_e <- factor(dat$per1_e, levels = c('narco', 'autodefensas member', 'local police officer',
                                     'federal police officer', 'soldier'))
dat$scen1_anger_st <- st(dat$scen1_anger)
dat$scen1_fear_st <- st(dat$scen1_fear)

m1a <- lm(as.formula(paste0('scen1_anger_st ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m1b <- lm(as.formula(paste0('scen1_anger_st ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m1c <- lm(as.formula(paste0('scen1_anger_st ~ ', spec1, spec2, spec25, spec3)), data = dat, weights = dat$scen1_here_pred)
m1d <- lm(as.formula(paste0('scen1_anger_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = dat$scen1_here_pred)
m1e <- lm(as.formula(paste0('scen1_anger_st ~ ', spec1, spec2, spec25, spec3, spec6)), data = dat, weights = dat$scen1_here_pred)

m2a <- lm(as.formula(paste0('scen1_fear_st ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m2b <- lm(as.formula(paste0('scen1_fear_st ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m2c <- lm(as.formula(paste0('scen1_fear_st ~ ', spec1, spec2, spec25, spec3)), data = dat, weights = dat$scen1_here_pred)
m2d <- lm(as.formula(paste0('scen1_fear_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = dat$scen1_here_pred)
m2e <- lm(as.formula(paste0('scen1_fear_st ~ ', spec1, spec2, spec25, spec3, spec6)), data = dat, weights = dat$scen1_here_pred)

## SEVERE/EXTRAJUDICIAL PUNISHMENT

dat$scen1_pun_sev_st <- st(dat$scen1_pun_sev)

m3a <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m3b <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m3c <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1, spec2, spec25, spec3)), data = dat, weights = dat$scen1_here_pred)
m3d <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = dat$scen1_here_pred)
m3e <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1, spec2, spec3, spec25, spec6)), data = dat, weights = dat$scen1_here_pred)

m4a <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m4b <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m4c <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1, spec2, spec25, spec3)), data = dat, weights = dat$scen1_here_pred)
m4d <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1, spec2, spec3, spec5)), data = dat, weights = dat$scen1_here_pred)
m4e <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1, spec2, spec3, spec25, spec6)), data = dat, weights = dat$scen1_here_pred)


## PRINCIPLE RANKING

m6a <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m6b <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m6d <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1, spec2, spec5)), data = dat, weights = dat$scen1_here_pred)
m6e <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1, spec2, spec25, spec6)), data = dat, weights = dat$scen1_here_pred)

m7a <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m7b <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m7d <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1, spec2, spec5)), data = dat, weights = dat$scen1_here_pred)
m7e <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1, spec2, spec25, spec6)), data = dat, weights = dat$scen1_here_pred)

m8a <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1)), data = dat, weights = dat$scen1_here_pred)
m8b <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1, spec2, spec25)), data = dat, weights = dat$scen1_here_pred)
m8d <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1, spec2, spec5)), data = dat, weights = dat$scen1_here_pred)
m8e <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1, spec2, spec25, spec6)), data = dat, weights = dat$scen1_here_pred)




#####
## big coefficient plot
#####

coefs <- c(summary(m1b)$coef['scen1_vic_inno',1], summary(m2b)$coef['scen1_vic_inno',1], 
           summary(m3b)$coef['scen1_vic_inno',1], summary(m4b)$coef['scen1_vic_inno',1],
           summary(m6b)$coef['scen1_vic_inno',1], summary(m7b)$coef['scen1_vic_inno',1],
           summary(m8b)$coef['scen1_vic_inno',1],
           summary(m1b)$coef['scen1_vio_sev',1], summary(m2b)$coef['scen1_vio_sev',1], 
           summary(m3b)$coef['scen1_vio_sev',1], summary(m4b)$coef['scen1_vio_sev',1],
           summary(m6b)$coef['scen1_vio_sev',1], summary(m7b)$coef['scen1_vio_sev',1],
           summary(m8b)$coef['scen1_vio_sev',1])
ses <- c(summary(m1b)$coef['scen1_vic_inno',2], summary(m2b)$coef['scen1_vic_inno',2], 
         summary(m3b)$coef['scen1_vic_inno',2], summary(m4b)$coef['scen1_vic_inno',2],
         summary(m6b)$coef['scen1_vic_inno',2], summary(m7b)$coef['scen1_vic_inno',2],
         summary(m8b)$coef['scen1_vic_inno',2],
         summary(m1b)$coef['scen1_vio_sev',2], summary(m2b)$coef['scen1_vio_sev',2], 
         summary(m3b)$coef['scen1_vio_sev',2], summary(m4b)$coef['scen1_vio_sev',2],
         summary(m6b)$coef['scen1_vio_sev',2], summary(m7b)$coef['scen1_vio_sev',2],
         summary(m8b)$coef['scen1_vio_sev',2])
         
plotdat <- data.frame('Outcome' = rep(c("Anger", "Fear", "Harsh Punishment", "Vigilante Punishment",
                                    "Punitiveness Rank=1", "Legality Rank=1", "Effectiveness Rank=1"), 2), 
                      'Treatment' = c(rep("Victim: Innocence",7),rep('Violence: Severity',7)), 
                      coefs, ses, 
                      'x' = seq(1,14,1),
                      'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)
plotdat$Outcome <- ordered(plotdat$Outcome, levels = c("Anger", "Fear", "Harsh Punishment", "Vigilante Punishment",
                                                       "Punitiveness Rank=1", "Legality Rank=1", "Effectiveness Rank=1"))

pdf('03_Figures/03_Conjoint/coefs_all.pdf')
ggplot(plotdat, aes(colour = Outcome)) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Outcome, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Outcome, y = coefs), 
             position = position_dodge(width=1/2), size = 3) +
  scale_colour_grey() +
  theme_minimal() +
  theme(text = element_text(size = 18), legend.position = 'bottom',
        axis.text.x = element_blank(), legend.title = element_blank()) +
  scale_y_continuous(name = 'Standardized Treatment Effect') +
  facet_grid(cols = vars(Treatment)) +
  guides(col=guide_legend(ncol=2))
dev.off()


#####
## APPENDIX TABLE G.1 and G.2 - Interaction w state capaicty
#####

stargazer(m3d, m3e, m4d, m4e, 
          no.space = T, keep.stat = c('n', 'rsq'),
          keep = c('scen1', 
                   'secmindist', 'groups.sec',
                   'Constant'),
          covariate.labels = c("Victim: Innocence", 'Violence: Severity',
                               'Proximity to Security Base', 'Presence of State Security',
                               "Victim: Innocence $\\times$ Violence: Severity",
                               "Victim: Innocence $\\times$ Prox. to Security Base",
                               "Violence: Severity $\\times$ Prox. to Security Base",
                               "Victim: Innocence $\\times$ Presence of State Security",
                               "Violence: Severity $\\times$ Presence of State Security",
                               'Constant'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          # title = "Characteristics of scenarios that would lead participants to prefer harsher and extrajudicial punishments",
          label = "tab:con_punish_interactions",
          dep.var.labels = c('', 'Harsh Punishment', '', '', 'Vigilante Punishment', ''))


stargazer(m6d, m6e, m7d, m7e, m8d, m8e, 
          no.space = T, keep.stat = c('n', 'rsq'),
          keep = c('scen1', 
                   'secmindist', 'groups.sec',
                   'Constant'),
          covariate.labels = c("Victim: Innocence", 'Violence: Severity',
                               'Proximity to Security Base', 'Presence of State Security',
                               "Victim: Innocence $\\times$ Violence: Severity",
                               "Victim: Innocence $\\times$ Prox. to Security Base",
                               "Violence: Severity $\\times$ Prox. to Security Base",
                               "Victim: Innocence $\\times$ Presence of State Security",
                               "Violence: Severity $\\times$ Presence of State Security",
                               'Constant'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01),
          # title = "Characteristics of scenarios that would lead participants to prefer harsher and extrajudicial punishments",
          label = "tab:con_prin_interactions",
          dep.var.labels = c('Severity Rank=1',  '', 'Legality Rank=1',  '', 'Effectiveness Rank=1', ''))





#####
## APPENDIX H: MEDIATION ANALYSIS
#####

## Acharya Blackwell Sen DirectEffect

form_main <- scen1_pun_sev_st ~ scen1_vic_inno + scen1_vio_sev + per1_e + female + insec_exp_index + education + 
  education + assets_index + age + married + employed_hh + psu |
  scen1_fear_st | scen1_anger_st
direct <- sequential_g(form_main, data = dat, 
                       weights = w_ag)
summary(direct)

sens <- cdesens(direct, var = "scen1_vic_inno")

pdf('03_Figures/03_Conjoint/DirectEffect_VicInno_Sens.pdf')
plot(sens)
dev.off()


## main estimate for plot 

spec1 <- 'scen1_vic_inno + scen1_vio_sev + per1_e'
spec2 <- '+ insec_exp_index + female + education + assets_index + age + married + employed_hh'
spec25 <- ' + psu'

m1b <- lm(as.formula(paste0('scen1_pun_sev_st ~ ', spec1, spec2, spec25)), data = dat,
          weights = dat$w_ag)

min(sens$rho[sens$acde > m1b$coefficients['scen1_vic_inno']])


  ## plot victim innocence mediation

tab <- data.frame('estimand' = c('ols', 'acde'),
                  'estimate' = c(m1b$coefficients['scen1_vic_inno'],
                                 direct$coefficients['scen1_vic_inno']),
                  'ses' = c(m1b$se['scen1_vic_inno'],
                            summary(direct)$coefficients['scen1_vic_inno','Std. Err.']))
tab$up95 <- tab$estimate + 1.96*tab$ses
tab$lo95 <- tab$estimate - 1.96*tab$ses
tab$estimand <- ordered(tab$estimand, levels = c('ols', 'acde'))

sens <- cdesens(direct, var = "scen1_vio_sev")

pdf('03_Figures/03_Conjoint/DirectEffect_VioSev_Sens.pdf')
plot(sens)
dev.off()


pdf("03_Figures/03_Conjoint/DirectEffect_VicInno.pdf")
ggplot(tab, aes(x = estimand)) +
  geom_point(aes(y = estimate)) +
  geom_errorbar(aes(ymin = lo95, ymax = up95),
                lwd = 1, width = 0.25) +
  geom_hline(aes(yintercept = 0), lty = 2) +
  theme_minimal() +
  theme(text = element_text(size = 28)) +
  scale_x_discrete(name = "", breaks = c('ols', 'acde'), labels = c("Total Effect", "ACDE")) +
  ylab("Estimated Coefficient")
dev.off()

tab$estimate[tab$estimand=='acde']/tab$estimate[tab$estimand=='ols']


  ## Violence Severity
tab <- data.frame('estimand' = c('ols', 'acde'),
                  'estimate' = c(m1b$coefficients['scen1_vio_sev'],
                                 direct$coefficients['scen1_vio_sev']),
                  'ses' = c(m1b$se['scen1_vio_sev'],
                            summary(direct)$coefficients['scen1_vio_sev','Std. Err.']))
tab$up95 <- tab$estimate + 1.96*tab$ses
tab$lo95 <- tab$estimate - 1.96*tab$ses
tab$estimand <- ordered(tab$estimand, levels = c('ols', 'acde'))

pdf("03_Figures/03_Conjoint/DirectEffect_VioSev.pdf")
ggplot(tab, aes(x = estimand)) +
  geom_point(aes(y = estimate)) +
  geom_errorbar(aes(ymin = lo95, ymax = up95),
                lwd = 1, width = 0.25) +
  geom_hline(aes(yintercept = 0), lty = 2) +
  theme_minimal() +
  theme(text = element_text(size = 28)) +
  scale_x_discrete(name = "", breaks = c('ols', 'acde'), labels = c("Total Effect", "ACDE")) +
  ylab("Estimated Coefficient")
dev.off()

tab$estimate[tab$estimand=='acde']/tab$estimate[tab$estimand=='ols']




#####
## APPENDIX G.3: Disaggregated by treatment condition
#####

dat$vic1_e <- factor(dat$vic1_e, levels = c('soldier', 'student', 'grandmother', 'local small business owner', 'narco'))
dat$vio1_e <- factor(dat$vio1_e, levels = c('extorted for money', 'disappeared', 'killed', 'tortured', 'robbed'))
dat$per1_e <- factor(dat$per1_e, levels = c('autodefensas member', 'federal police officer', 'local police officer',
                                            'narco', 'soldier'))

m1a <- lm(as.formula(paste0('scen1_anger ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m1b <- lm(as.formula(paste0('scen1_anger ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m1c <- lm(as.formula(paste0('scen1_anger ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)

m2a <- lm(as.formula(paste0('scen1_fear ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m2b <- lm(as.formula(paste0('scen1_fear ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m2c <- lm(as.formula(paste0('scen1_fear ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)

## plot coefficients - anger ~ victim

coefs <- c(0, summary(m1b)$coef['vic1_estudent',1], summary(m1b)$coef['vic1_egrandmother',1],
           summary(m1b)$coef['vic1_elocal small business owner',1], summary(m1b)$coef['vic1_enarco',1])
ses <- c(0, summary(m1b)$coef['vic1_estudent',2], summary(m1b)$coef['vic1_egrandmother',2],
         summary(m1b)$coef['vic1_elocal small business owner',2], summary(m1b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/anger_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - fear ~ victim

coefs <- c(0, summary(m2b)$coef['vic1_estudent',1], summary(m2b)$coef['vic1_egrandmother',1],
           summary(m2b)$coef['vic1_elocal small business owner',1], summary(m2b)$coef['vic1_enarco',1])
ses <- c(0, summary(m2b)$coef['vic1_estudent',2], summary(m2b)$coef['vic1_egrandmother',2],
         summary(m2b)$coef['vic1_elocal small business owner',2], summary(m2b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/fear_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - anger ~ violence

coefs <- c(0, summary(m1b)$coef['vio1_edisappeared',1], summary(m1b)$coef['vio1_ekilled',1],
           summary(m1b)$coef['vio1_etortured',1], summary(m1b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m1b)$coef['vio1_edisappeared',2], summary(m1b)$coef['vio1_ekilled',2],
         summary(m1b)$coef['vio1_etortured',2], summary(m1b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                  levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/anger_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - fear ~ violence

coefs <- c(0, summary(m2b)$coef['vio1_edisappeared',1], summary(m2b)$coef['vio1_ekilled',1],
           summary(m2b)$coef['vio1_etortured',1], summary(m2b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m2b)$coef['vio1_edisappeared',2], summary(m2b)$coef['vio1_ekilled',2],
         summary(m2b)$coef['vio1_etortured',2], summary(m2b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/fear_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - anger ~ perpetrator

coefs <- c(0, summary(m1b)$coef['per1_efederal police officer',1], summary(m1b)$coef['per1_elocal police officer',1],
           summary(m1b)$coef['per1_enarco',1], summary(m1b)$coef['per1_esoldier',1])
ses <- c(0, summary(m1b)$coef['per1_efederal police officer',2], summary(m1b)$coef['per1_elocal police officer',2],
         summary(m1b)$coef['per1_enarco',2], summary(m1b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                    levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/anger_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - fear ~ perpetrator

coefs <- c(0, summary(m2b)$coef['per1_efederal police officer',1], summary(m2b)$coef['per1_elocal police officer',1],
           summary(m2b)$coef['per1_enarco',1], summary(m2b)$coef['per1_esoldier',1])
ses <- c(0, summary(m2b)$coef['per1_efederal police officer',2], summary(m2b)$coef['per1_elocal police officer',2],
         summary(m2b)$coef['per1_enarco',2], summary(m2b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/fear_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()




#####
## APPENDIX G.3: punishment preferences disaggregated
#####

m1a <- lm(as.formula(paste0('scen1_pun_sev ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m1b <- lm(as.formula(paste0('scen1_pun_sev ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m1c <- lm(as.formula(paste0('scen1_pun_sev ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)

m2a <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m2b <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m2c <- lm(as.formula(paste0('scen1_pun_extrajud ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)


## plot coefficients - sev ~ victim

coefs <- c(0, summary(m1b)$coef['vic1_estudent',1], summary(m1b)$coef['vic1_egrandmother',1],
           summary(m1b)$coef['vic1_elocal small business owner',1], summary(m1b)$coef['vic1_enarco',1])
ses <- c(0, summary(m1b)$coef['vic1_estudent',2], summary(m1b)$coef['vic1_egrandmother',2],
         summary(m1b)$coef['vic1_elocal small business owner',2], summary(m1b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/sev_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - extrajud ~ victim

coefs <- c(0, summary(m2b)$coef['vic1_estudent',1], summary(m2b)$coef['vic1_egrandmother',1],
           summary(m2b)$coef['vic1_elocal small business owner',1], summary(m2b)$coef['vic1_enarco',1])
ses <- c(0, summary(m2b)$coef['vic1_estudent',2], summary(m2b)$coef['vic1_egrandmother',2],
         summary(m2b)$coef['vic1_elocal small business owner',2], summary(m2b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/extrajud_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - sev ~ violence

coefs <- c(0, summary(m1b)$coef['vio1_edisappeared',1], summary(m1b)$coef['vio1_ekilled',1],
           summary(m1b)$coef['vio1_etortured',1], summary(m1b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m1b)$coef['vio1_edisappeared',2], summary(m1b)$coef['vio1_ekilled',2],
         summary(m1b)$coef['vio1_etortured',2], summary(m1b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/sev_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - fear ~ violence

coefs <- c(0, summary(m2b)$coef['vio1_edisappeared',1], summary(m2b)$coef['vio1_ekilled',1],
           summary(m2b)$coef['vio1_etortured',1], summary(m2b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m2b)$coef['vio1_edisappeared',2], summary(m2b)$coef['vio1_ekilled',2],
         summary(m2b)$coef['vio1_etortured',2], summary(m2b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/extrajud_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - sev ~ perpetrator

coefs <- c(0, summary(m1b)$coef['per1_efederal police officer',1], summary(m1b)$coef['per1_elocal police officer',1],
           summary(m1b)$coef['per1_enarco',1], summary(m1b)$coef['per1_esoldier',1])
ses <- c(0, summary(m1b)$coef['per1_efederal police officer',2], summary(m1b)$coef['per1_elocal police officer',2],
         summary(m1b)$coef['per1_enarco',2], summary(m1b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/sev_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - extrajud ~ perpetrator

coefs <- c(0, summary(m2b)$coef['per1_efederal police officer',1], summary(m2b)$coef['per1_elocal police officer',1],
           summary(m2b)$coef['per1_enarco',1], summary(m2b)$coef['per1_esoldier',1])
ses <- c(0, summary(m2b)$coef['per1_efederal police officer',2], summary(m2b)$coef['per1_elocal police officer',2],
         summary(m2b)$coef['per1_enarco',2], summary(m2b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/extrajud_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()





#####
## FIGURE G6: rank of punitiveness
#####

m1a <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m1b <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m1c <- lm(as.formula(paste0('scen1_prin_rank_sev ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)

m2a <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m2b <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m2c <- lm(as.formula(paste0('scen1_prin_rank_legal ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)

m3a <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1d)), data = dat, weights = dat$scen1_here_pred)
m3b <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1d, spec2)), data = dat, weights = dat$scen1_here_pred)
m3c <- lm(as.formula(paste0('scen1_prin_rank_prev ~ ', spec1d, spec2, spec3d)), data = dat, weights = dat$scen1_here_pred)


## plot coefficients - punitiveness principle ~ victim

coefs <- c(0, summary(m1b)$coef['vic1_estudent',1], summary(m1b)$coef['vic1_egrandmother',1],
           summary(m1b)$coef['vic1_elocal small business owner',1], summary(m1b)$coef['vic1_enarco',1])
ses <- c(0, summary(m1b)$coef['vic1_estudent',2], summary(m1b)$coef['vic1_egrandmother',2],
         summary(m1b)$coef['vic1_elocal small business owner',2], summary(m1b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_sev_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - legality principle ~ victim

coefs <- c(0, summary(m2b)$coef['vic1_estudent',1], summary(m2b)$coef['vic1_egrandmother',1],
           summary(m2b)$coef['vic1_elocal small business owner',1], summary(m2b)$coef['vic1_enarco',1])
ses <- c(0, summary(m2b)$coef['vic1_estudent',2], summary(m2b)$coef['vic1_egrandmother',2],
         summary(m2b)$coef['vic1_elocal small business owner',2], summary(m2b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_legal_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - effectiveness principle ~ victim

coefs <- c(0, summary(m3b)$coef['vic1_estudent',1], summary(m3b)$coef['vic1_egrandmother',1],
           summary(m3b)$coef['vic1_elocal small business owner',1], summary(m3b)$coef['vic1_enarco',1])
ses <- c(0, summary(m3b)$coef['vic1_estudent',2], summary(m3b)$coef['vic1_egrandmother',2],
         summary(m3b)$coef['vic1_elocal small business owner',2], summary(m3b)$coef['vic1_enarco',2])
p <- data.frame('Victim' = factor(c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco'),
                                  levels = c('Base Case (Soldier)', 'Student', 'Grandmother', 'Business Owner', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_prev_vic_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Victim, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Victim, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - punitiveness principle ~ violence

coefs <- c(0, summary(m1b)$coef['vio1_edisappeared',1], summary(m1b)$coef['vio1_ekilled',1],
           summary(m1b)$coef['vio1_etortured',1], summary(m1b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m1b)$coef['vio1_edisappeared',2], summary(m1b)$coef['vio1_ekilled',2],
         summary(m1b)$coef['vio1_etortured',2], summary(m1b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_sev_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - legality principle ~ violence

coefs <- c(0, summary(m2b)$coef['vio1_edisappeared',1], summary(m2b)$coef['vio1_ekilled',1],
           summary(m2b)$coef['vio1_etortured',1], summary(m2b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m2b)$coef['vio1_edisappeared',2], summary(m2b)$coef['vio1_ekilled',2],
         summary(m2b)$coef['vio1_etortured',2], summary(m2b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_legal_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - effectiveness principle ~ violence

coefs <- c(0, summary(m3b)$coef['vio1_edisappeared',1], summary(m3b)$coef['vio1_ekilled',1],
           summary(m3b)$coef['vio1_etortured',1], summary(m3b)$coef['vio1_erobbed',1])
ses <- c(0, summary(m3b)$coef['vio1_edisappeared',2], summary(m3b)$coef['vio1_ekilled',2],
         summary(m3b)$coef['vio1_etortured',2], summary(m3b)$coef['vio1_erobbed',2])
p <- data.frame('Violence' = factor(c('Base Case (Extorted)', 'Disappeared', 'Killed', 'Tortured', 'Robbed'),
                                    levels = c('Base Case (Extorted)', 'Killed', 'Disappeared', 'Tortured', 'Robbed')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_prev_vio_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Violence, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Violence, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()



## plot coefficients - punitiveness principle ~ perpetrator

coefs <- c(0, summary(m1b)$coef['per1_efederal police officer',1], summary(m1b)$coef['per1_elocal police officer',1],
           summary(m1b)$coef['per1_enarco',1], summary(m1b)$coef['per1_esoldier',1])
ses <- c(0, summary(m1b)$coef['per1_efederal police officer',2], summary(m1b)$coef['per1_elocal police officer',2],
         summary(m1b)$coef['per1_enarco',2], summary(m1b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_sev_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - legality principle ~ perpetrator

coefs <- c(0, summary(m2b)$coef['per1_efederal police officer',1], summary(m2b)$coef['per1_elocal police officer',1],
           summary(m2b)$coef['per1_enarco',1], summary(m2b)$coef['per1_esoldier',1])
ses <- c(0, summary(m2b)$coef['per1_efederal police officer',2], summary(m2b)$coef['per1_elocal police officer',2],
         summary(m2b)$coef['per1_enarco',2], summary(m2b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_legal_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()


## plot coefficients - prevention principle ~ perpetrator

coefs <- c(0, summary(m3b)$coef['per1_efederal police officer',1], summary(m3b)$coef['per1_elocal police officer',1],
           summary(m3b)$coef['per1_enarco',1], summary(m3b)$coef['per1_esoldier',1])
ses <- c(0, summary(m3b)$coef['per1_efederal police officer',2], summary(m3b)$coef['per1_elocal police officer',2],
         summary(m3b)$coef['per1_enarco',2], summary(m3b)$coef['per1_esoldier',2])
p <- data.frame('Perpetrator' = factor(c('Base Case (Autodefensa)', 'Federal Police', 'Local Police', 'Narco', 'Soldier'),
                                       levels = c('Base Case (Autodefensa)', 'Soldier', 'Federal Police', 'Local Police', 'Narco')),
                'Coefficient' = coefs, ses, 
                'up95' = coefs + 1.96*ses, 'lo95' = coefs - 1.96*ses)

pdf('03_Figures/03_Conjoint/prin_prev_per_disagg_coefs.pdf')
ggplot(p) +
  geom_hline(yintercept = 0, colour = gray(1/2), lty = 2) +
  geom_errorbar(aes(x = Perpetrator, ymin = lo95, ymax = up95),
                lwd = 1, position = position_dodge(width = 1/2),
                width = 0.25) +
  geom_point(aes(x = Perpetrator, y = Coefficient), 
             position = position_dodge(width=1/2)) +
  theme_minimal() +
  theme(text = element_text(size = 20),
        axis.text.x = element_text(angle = 45, hjust = 1)) 
dev.off()







##########
## Appendix A: Survey conduct
##########

#####
## FIGURE A5: age histogram
#####

pdf('03_Figures/04_SummStats/age_dist.pdf')
cols <- c("uw"="#f04546","w"="#3591d1","locw"="green")
ggplot(dat) +
  geom_histogram(aes(age, weight = 1), bins = 20, fill = cols[1], alpha = 0.2) +
  geom_histogram(aes(age, weight = w_ag), bins = 20, fill = cols[2], alpha = 0.2) +
  # geom_histogram(aes(age, weight = w), bins = 20, fill = cols[3], alpha = 0.2) +
  theme_minimal() +
  theme(text = element_text(size=24)) +
  xlab("Age") +
  ylab("Weighted Count") +
  scale_fill_manual(name="Data", values=cols)
dev.off()



#####
## TABLE A1: weighted/unweighted demographics
#####

vars = c('age', 'female', 'married', 'kids', 'employed_hh', 'education', 
         'home_owner', 'table_assets.fridge', 'table_assets.washing', 
         'table_assets.cell', 'table_assets.smartphone', 'table_assets.computer',
         'trauma_armed', 'trauma_extortion', 'trauma_confined',
         'fear_pre', 'nervous_pre', 'anger_pre', 'indignant_pre',
         'happy_pre', 'cheerful_pre', 'sad_pre', 'dejected_pre',
         'mich', 'coli', 'jali', 'naya')


## unweighted

coefs = data.frame('mean' = rep(NA, length(vars)), 
                   'se' = rep(NA,length(vars)), 
                   'N' = rep(NA, length(vars)))
for (v in 1:length(vars)){
  c <- mean(dat[,vars[v]], na.rm=T)
  se <- sd(dat[,vars[v]], na.rm=T)/sqrt(length(na.omit(dat[,vars[v]])))
  n <- length(na.omit(dat[,vars[v]]))
  coefs[v,] <- c(c, se, n)
}

rownames(coefs) = vars
xtable(coefs)



## weighted

coefs = data.frame('mean' = rep(NA, length(vars)), 
                   'se' = rep(NA,length(vars)), 
                   'N' = rep(NA, length(vars)))
for (v in 1:length(vars)){
  c <- wtd.mean(dat[,vars[v]], weights = dat$w, na.rm=T)
  se <- sqrt(wtd.var(dat[,vars[v]], weights = dat$w, na.rm=T))/sqrt(length(na.omit(dat[,vars[v]])))
  n <- length(na.omit(dat[,vars[v]]))
  coefs[v,] <- c(c, se, n)
}

rownames(coefs) = vars
xtable(coefs)


## weights - locality, age, gender
coefs = data.frame('mean' = rep(NA, length(vars)), 
                   'se' = rep(NA,length(vars)), 
                   'N' = rep(NA, length(vars)))
for (v in 1:length(vars)){
  c <- wtd.mean(dat[,vars[v]], weights = dat$w_ag, na.rm=T)
  se <- sqrt(wtd.var(dat[,vars[v]], weights = dat$w_ag, na.rm=T))/sqrt(length(na.omit(dat[,vars[v]])))
  n <- length(na.omit(dat[,vars[v]]))
  coefs[v,] <- c(c, se, n)
}

rownames(coefs) = vars
xtable(coefs)




##########
## Appendix B: MEASURE VALIDATION
##########

#####
## TABLES B1 AND B2: INDEX VALIDATION
#####

  ## build harsh punishment and pro-vigilantes indices

auto_vars <- c('pol_armed_st', 'pol_auto_st', 'pol_tech_st')
harsh_vars <- c('pol_death_st', 'pol_narcos_rev_st')

  ## correlation tables
xtable(cor(dat[,c(harsh_vars, auto_vars)], use = "complete.obs"))


dat$pol_auto_index <- rowMeans(dat[,auto_vars], na.rm=T)
dat$pol_harsh_index <- rowMeans(dat[,harsh_vars], na.rm=T)

  ## look at correlation tables
xtable(cor(dat[,c(auto_vars)], use = "complete.obs"))
xtable(cor(dat[,c(harsh_vars)], use = "complete.obs"))



##########
## APPENDIX C: SUMMARY STATS
##########

#####
## APPENDIX TABLE C1
#####

vars <- c('female', 'education', 'table_assets.fridge', 'table_assets.washing', 'table_assets.cell',
          'table_assets.smartphone', 'table_assets.computer', 'age', 'married', 'employed_hh')
tab <- data.frame('mean' = rep(NA, length(vars)), 'sd' = rep(NA, length(vars)), 'min' = rep(NA, length(vars)),
                  'max' = rep(NA, length(vars)), 'N' = rep(NA, length(vars)))
tab$mean <- apply(dat[,vars], MARGIN = 2, FUN = mean, na.rm = T)
tab$sd <- apply(dat[,vars], MARGIN = 2, FUN = sd, na.rm = T)
tab$min <- apply(dat[,vars], MARGIN = 2, FUN = min, na.rm = T)
tab$max <- apply(dat[,vars], MARGIN = 2, FUN = max, na.rm = T)
tab$N <- apply(dat[,vars], MARGIN = 2, FUN = function(x) length(na.omit(x)))
rownames(tab) <- vars
xtable(tab)



##########
## Appendix D: VIOLENCE VALIDATION
##########

## TABLE D1: validation of indirect measures

m1a <- lm(st(insec_extortion) ~ trauma_extortion, data = dat, weights = w_ag)
m1b <- lm(st(insec_extortion) ~ trauma_extortion + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name), data = dat, weights = w_ag)
m1c <- lm(st(insec_extortion) ~ trauma_extortion + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name) + as.factor(psu), data = dat, weights = w_ag)
m1c$psu_no <- length(unique(m1c$model[,'as.factor(psu)']))

m2a <- lm(st(insec_blockade) ~ trauma_blockade, data = dat, weights = w_ag)
m2b <- lm(st(insec_blockade) ~ trauma_blockade + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name), data = dat, weights = w_ag)
m2c <- lm(st(insec_blockade) ~ trauma_blockade + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name) + as.factor(psu), data = dat, weights = w_ag)
m2c$psu_no <- length(unique(m2c$model[,'as.factor(psu)']))

m3a <- lm(st(insec_banner) ~ trauma_banner, data = dat, weights = w_ag)
m3b <- lm(st(insec_banner) ~ trauma_banner + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name), data = dat, weights = w_ag)
m3c <- lm(st(insec_banner) ~ trauma_banner + female + age + education + assets_index + married + employed_hh
          + as.factor(surveyor_name) + as.factor(psu), data = dat, weights = w_ag)
m3c$psu_no <- length(unique(m3c$model[,'as.factor(psu)']))

stargazer(m1a, m1b, m1c, m2a, m2b, m2c, m3a, m3b, m3c,
          keep = c('trauma'), keep.stat = c('rsq', 'n'),
          no.space = T, digits = 2,
          add.lines = list(c("Individual Controls", "", "\\checkmark", "\\checkmark", "", "\\checkmark", "\\checkmark", "", "\\checkmark", "\\checkmark"),
                           c("PSU FE", "", "", "\\checkmark", "", "", "\\checkmark", "", "", "\\checkmark"),
                           c("Number of PSUs", "", "", m1c$psu_no, "", "", m2c$psu_no, "", "", m2c$psu_no)),
          covariate.labels = c('Extortion (Direct)', 'Blockade (Direct)', 'Banner (Direct)'),
          dep.var.labels = c('Extortion (Indirect)', 'Blockade (Indirect)', 'Banner (Indirect)'),
          star.char = c("\\dagger", "*", "**"),
          star.cutoffs = c(.1, .05, .01)
          )

cor(dat$insec_extortion, dat$trauma_extortion, use = 'complete.obs')
cor(dat$insec_blockade, dat$trauma_blockade, use = 'complete.obs')
cor(dat$insec_banner, dat$trauma_banner, use = 'complete.obs')

## indirect q's are good predictors of direct exposure


## correlation with treatmnet

summary(lm(trauma_index ~ treat_assign, data = dat, weights = w_ag))
summary(lm(insec_index ~ treat_assign, data = dat, weights = w_ag))


## how much variation do PSU FE explain? 

m1a <- lm(insec_abduction ~ as.factor(psu), data = dat, weights = w_ag)
m1b <- lm(insec_abduction ~ as.factor(psu) + female + age + education + assets_index + married + employed_hh, data = dat, weights = w_ag)
m2a <- lm(insec_extortion ~ as.factor(psu), data = dat, weights = w_ag)
m2b <- lm(insec_extortion ~ as.factor(psu) + female + age + education + assets_index + married + employed_hh, data = dat, weights = w_ag)
m3a <- lm(insec_protection ~ as.factor(psu), data = dat, weights = w_ag)
m3b <- lm(insec_protection ~ as.factor(psu) + female + age + education + assets_index + married + employed_hh, data = dat, weights = w_ag)
m4a <- lm(insec_weapon ~ as.factor(psu), data = dat, weights = w_ag)
m4b <- lm(insec_weapon ~ as.factor(psu) + female + age + education + assets_index + married + employed_hh, data = dat, weights = w_ag)
m5a <- lm(insec_assault ~ as.factor(psu), data = dat, weights = w_ag)
m5b <- lm(insec_assault ~ as.factor(psu) + female + age + education + assets_index + married + employed_hh, data = dat, weights = w_ag)

stargazer(m1a, m1b, m2a, m2b, m3a, m3b, m4a, m4b, m5a, m5b, 
          keep = c('female', 'age', 'education', 'assets', 'marital', 'employ', 'Constant'),
          no.space = T, digits = 2, keep.stat = c('rsq', 'n'))

# 
# #####
# ## XX validation of state capacity data
# #####
# 
# 
# m1a <- lm(groups.army ~ milmindist_log_rev_st, data = dat)
# m1a$se <- coeftest(m1a, vcov = cluster.vcov(m1a, dat$MUNICIPIO.x))[,2]
# m1b <- lm(groups.army ~ milmindist_log_rev_st + homdrate17 + Urban.x, data = dat)
# m1b$se <- coeftest(m1b, vcov = cluster.vcov(m1b, dat$MUNICIPIO.x))[,2]
# 
# m2a <- lm(groups.police ~ polmindist_log_rev_st, data = dat)
# m2a$se <- coeftest(m2a, vcov = cluster.vcov(m2a, dat$MUNICIPIO.x))[,2]
# m2b <- lm(groups.police ~ polmindist_log_rev_st + homdrate17 + Urban.x, data = dat)
# m2b$se <- coeftest(m2b, vcov = cluster.vcov(m2b, dat$MUNICIPIO.x))[,2]
# 
# stargazer(m1a, m1b, m2a, m2b,
#           se=list(m1a$se, m1b$se, m2a$se, m2b$se))
# 
# 
# t <- melt(dat, id.vars = c('MUNICIPIO.x'),
#           measure.vars = c('milmindist_log_rev_st', 'polmindist_log_rev_st', 'groups.army', 'groups.police'),
#           subset=is.na(dat$MUNICIPIO.x)==F)
# t <- cast(t, MUNICIPIO.x ~ variable, mean, na.rm=T)
# 
# plot(x = t$milmindist_log_rev_st, y = t$groups.army)
# plot(x = t$polmindist_log_rev_st, y = t$groups.police)
# 
# vars <- c('milmindist_log_rev_st', 'polmindist_log_rev_st', 'groups.army', 'groups.police')
# 
# cormat <- round(cor(dat[,vars], use = 'complete.obs'),2)
# 
# cormat <- na.omit(melt(cormat, na.rm=T))
# cormat$Var1 <- car::recode(cormat$X1, "'milmindist_log_rev_st'='Proximity to Military';
#                            'polmindist_log_rev_st'='Proximity to Police';
#                            'groups.army'='Presence of Army';'groups.police'='Presence of Police'")
# cormat$Var2 <- car::recode(cormat$X2, "'milmindist_log_rev_st'='Proximity to Military';
#                            'polmindist_log_rev_st'='Proximity to Police';
#                            'groups.army'='Presence of Army';'groups.police'='Presence of Police'")
# 
# ggplot(data = cormat, aes(x=Var1, y=Var2, fill=value)) + 
#   geom_tile(color = "white") +
#   geom_text(aes(label = value), color = "black", size = 4) +
#   theme_minimal() +
#   theme(text = element_text(size=14)) +
#   scale_fill_gradient2(low = "blue", high = "red", mid = "white", 
#                        midpoint = 0, limit = c(-1,1), space = "Lab", 
#                        name="Pearson\nCorrelation") +
#   coord_fixed()
# 
