


############################################################################################
############################################################################################
## Violence, anger + punitiveness in Mexico                                               ##
## GP, Young & Zeitzoff                                                                   ##
## CLEANING                                                                               ##
## Jul 2021                                                                               ##
############################################################################################
############################################################################################


##########
## PRELIMS
##########

rm(list=ls())

library(lubridate)
library(data.table)
library(car)
# library(dplyr)
library(gdata)
library(gtools)

options(scipen = 100000000) 

setwd('/Users/leyou/Dropbox/YoungZeitzoff_Emotions/10_Analysis/03_GPYZ_RepPackage')


#####
## functions
#####

## standardize based on control group SDs
st_out <- function(x, data = dat, treat = 'treat_all') {
  (x - mean(x[data[,treat]==0],na.rm=T))/sd(x[data[,treat]==0],na.rm=T)
}

## standardize based on total population SDs
st <- function(x) {
  (x - mean(x,na.rm=T))/sd(x,na.rm=T)
}


## function to remove NAs
replace_NA <- function(data, varnames, NAvals) {
  numvars <- length(varnames)
  numNA <- length(NAvals)
  data <- as.data.frame(data)
  for (i in 1:numvars){
    varname <- varnames[i]
    for (j in 1:numNA) {
      data[,varname] <- ifelse(data[,varname]==NAvals[j], NA, data[,varname])
    }
  }
  return(data)
}



##########
## BUILD DATASETS
##########

dat <- read.csv('02_Data/02_Raw/data_main.csv')
hhs <- read.csv('02_Data/02_Raw/data_elig.csv')

## subset to hhs that consented

dat <- subset(dat, dat$hh_replace!="yes")


#####
## HH member roster
#####

## rename hh member roster

hhs <- subset(hhs, select = c(elig.elig_age, X_parent_index))
setnames(hhs, colnames(hhs), c('elig_age', 'hh_id'))
hhs$elig_id <- with(hhs, ave(rep(1, nrow(hhs)), hh_id, FUN = seq_along))
setnames(dat, 'X_index', 'hh_id')

## merge gender into hh member roster

t <- subset(dat, select = c(hh_id, select_gender_s))
t <- subset(t, duplicated(t$hh_id)==F) ## need to doublecheck this - some hhs may have two genders selected
t$elig_female <- ifelse(t$select_gender_s=="mujere", 1, 0)
t$select_gender_s=NULL
hhs <- merge(hhs, t, by = 'hh_id', all.x = T)

write.csv(hhs, '02_Data/03_Clean/roster_clean.csv')


## reshape family roster and merge into full data

hhsw <- reshape(hhs, dir = 'wide', idvar = 'hh_id', timevar = 'elig_id')
dat <- merge(dat, hhsw, by = 'hh_id', all.x = T)




##########
## INTERVIEW STATS
##########

#####
## interview length
#####

m <- regexpr("[0-9]{2}:[0-9]{2}:[0-9]{2}", dat$start)
dat$start_hms <- regmatches(dat$start, m)
dat$start_hms <- hms(dat$start_hms)

m <- regexpr("[0-9]{2}:[0-9]{2}:[0-9]{2}", dat$end)
dat$end_hms <- regmatches(dat$end, m)
dat$end_hms <- hms(dat$end_hms)


#####
## interview date
#####

dat$date <- strtrim(dat$start, 10)


#####
## replacement hh
#####

dat$replacement_hh <- as.numeric(as.character(dat$replacement_hh))



##########
## MINI EXPERIMENTS
##########

## treatment indicators

dat$treat_rage_child <- ifelse(grepl('the local population', dat$rage_e), 0, 1)
dat$treat_rage_graft <- ifelse(grepl('disabled children', dat$rage2_e), 1, 0)
dat$treat_rage_decap <- ifelse(grepl('beheaded', dat$rage3_e), 1, 0)


## collapse rage scenario randomizations

  ## child abuse

dat$rage_child_anger <- ifelse(dat$rage_order1 < 0.33, dat$rage_scen.rage_anger,
                                 dat$rage12_scen.rage12_anger)
dat$rage_child_fear <- ifelse(dat$rage_order1 < 0.33, dat$rage_scen.rage_fear,
                               dat$rage12_scen.rage12_fear)
dat$rage_child_pref <- ifelse(dat$rage_order1 < 0.33, as.character(dat$rage_pref_page.rage_pref),
                              as.character(dat$rage12_pref_page.rage12_pref))
dat$rage_child_prev <- ifelse(dat$rage_order1 < 0.33, as.character(dat$rage_prev_page.rage_prev),
                              as.character(dat$rage12_prev_page.rage12_prev))
dat$rage_child_just <- ifelse(dat$rage_order1 < 0.33, as.character(dat$rage_just_page.rage_just),
                              as.character(dat$rage12_just_page.rage12_just))
dat$rage_child_prefB <- ifelse(dat$rage_child_pref=="B", 1, 0)
dat$rage_child_prevB <- ifelse(dat$rage_child_prev=="B", 1, 0)
dat$rage_child_justB <- ifelse(dat$rage_child_just=="B", 1, 0)


  ## graft

dat$rage_graft_anger <- ifelse(dat$rage_order2 < 0.33, dat$rage2_scen.rage2_anger,
                               ifelse(dat$rage_order2 < 0.66, dat$rage22_scen.rage22_anger,
                                      dat$rage23_scen.rage23_anger))
dat$rage_graft_fear <- ifelse(dat$rage_order2 < 0.33, dat$rage2_scen.rage2_fear,
                              ifelse(dat$rage_order2 < 0.66, dat$rage22_scen.rage22_fear,
                                     dat$rage23_scen.rage23_fear))
dat$rage_graft_pref <- ifelse(dat$rage_order2 < 0.33, as.character(dat$rage2_pref_page.rage2_pref),
                              ifelse(dat$rage_order2 < 0.66, as.character(dat$rage22_pref_page.rage22_pref),
                                     as.character(dat$rage23_pref_page.rage23_pref)))
dat$rage_graft_prev <- ifelse(dat$rage_order2 < 0.33, as.character(dat$rage2_prev_page.rage2_prev),
                              ifelse(dat$rage_order2 < 0.66, as.character(dat$rage22_prev_page.rage22_prev),
                                     as.character(dat$rage23_prev_page.rage23_prev)))
dat$rage_graft_just <- ifelse(dat$rage_order2 < 0.33, as.character(dat$rage2_just_page.rage2_just),
                              ifelse(dat$rage_order2 < 0.66, as.character(dat$rage22_just_page.rage22_just),
                                     as.character(dat$rage23_just_page.rage23_just)))
dat$rage_graft_prefB <- ifelse(dat$rage_graft_pref=="B", 1, 0)
dat$rage_graft_prevB <- ifelse(dat$rage_graft_prev=="B", 1, 0)
dat$rage_graft_justB <- ifelse(dat$rage_graft_just=="B", 1, 0)


  ## torture

dat$rage_decap_anger <- dat$rage3_scen.rage3_anger
dat$rage_decap_fear <- dat$rage3_scen.rage3_fear
dat$rage_decap_pref <- as.character(dat$rage3_pref_page.rage3_pref)
dat$rage_decap_prev <- as.character(dat$rage3_prev_page.rage3_prev)
dat$rage_decap_just <- as.character(dat$rage3_just_page.rage3_just)
dat$rage_decap_prefB <- ifelse(dat$rage_decap_pref=="B", 1, 0)
dat$rage_decap_prevB <- ifelse(dat$rage_decap_prev=="B", 1, 0)
dat$rage_decap_justB <- ifelse(dat$rage_decap_just=="B", 1, 0)

                            
## replace NAs
rage_outs_new <- c('rage_child_anger', 'rage_child_fear', 'rage_graft_anger', 'rage_graft_fear',
                   'rage_decap_anger', 'rage_decap_fear')
dat <- replace_NA(dat, rage_outs_new, -99)


## standardize
for (i in 1:length(rage_outs_new)){
  t <- st(dat[,rage_outs_new[i]])
  dat[,paste0(rage_outs_new[i], '_st')] <- t
}



#####
## priming experiment treatment
#####

dat$treat_assign <- factor(dat$treat_assign, levels = c("C", "A", "R"), ordered = T)


#####
## policy prefs - priming experiment outcomes
#####

## pay narcos
dat$pol_narcos <- ifelse(grepl("pay narcos to stop", dat$pol1_e), dat$pol_page.polpref_q1, 
                       ifelse(grepl("pay narcos to stop", dat$pol2_e), dat$pol_page.polpref_q2,
                              ifelse(grepl("pay narcos to stop", dat$pol3_e), dat$pol_page.polpref_q3,
                                     ifelse(grepl("pay narcos to stop", dat$pol4_e), dat$pol_page.polpref_q4, 
                                                          NA))))

## death penalty
dat$pol_death <- ifelse(grepl("bring back the death", dat$pol1_e), dat$pol_page.polpref_q1, 
                         ifelse(grepl("bring back the death", dat$pol2_e), dat$pol_page.polpref_q2,
                                ifelse(grepl("bring back the death", dat$pol3_e), dat$pol_page.polpref_q3,
                                       ifelse(grepl("bring back the death", dat$pol4_e), dat$pol_page.polpref_q4, 
                                              NA))))

## autodefensas
dat$pol_auto <- ifelse(grepl("autodefensas", dat$pol1_e), dat$pol_page.polpref_q1, 
                        ifelse(grepl("autodefensas", dat$pol2_e), dat$pol_page.polpref_q2,
                               ifelse(grepl("autodefensas", dat$pol3_e), dat$pol_page.polpref_q3,
                                      ifelse(grepl("autodefensas", dat$pol4_e), dat$pol_page.polpref_q4, 
                                             NA))))

## armed groups outside govt
dat$pol_armed <- ifelse(grepl("armed groups outside of the government", dat$pol1_e), dat$pol_page.polpref_q1, 
                       ifelse(grepl("armed groups outside of the government", dat$pol2_e), dat$pol_page.polpref_q2,
                              ifelse(grepl("armed groups outside of the government", dat$pol3_e), dat$pol_page.polpref_q3,
                                     ifelse(grepl("armed groups outside of the government", dat$pol4_e), dat$pol_page.polpref_q4, 
                                            NA))))


## remove NAs
dat <- replace_NA(dat, c('pol_narcos', 'pol_death', 'pol_auto', 'pol_armed',
                         'pol_chapo', 'pol_tech', 'pol_rurales'),
                  -99)


## reverse code if necessary
dat$pol_narcos_rev <- -1*dat$pol_narcos


## standardize
dat$pol_narcos_rev_st <- st(dat$pol_narcos_rev)
dat$pol_death_st <- st(dat$pol_death)
dat$pol_auto_st <- st(dat$pol_auto)
dat$pol_armed_st <- st(dat$pol_armed)
dat$pol_chapo_st <- st(dat$pol_chapo)
dat$pol_tech_st <- st(dat$pol_tech)
dat$pol_rurales_st <- st(dat$pol_rurales)


## make indices

auto_vars <- c('pol_armed_st', 'pol_auto_st', 'pol_tech_st')
harsh_vars <- c('pol_death_st', 'pol_narcos_rev_st')

dat$pol_all_st <- rowMeans(dat[,c(auto_vars, harsh_vars, 
                                  'pol_chapo_st', 'pol_rurales_st')], na.rm=T)
dat$pol_auto_index <- rowMeans(dat[,auto_vars], na.rm=T)
dat$pol_harsh_index <- rowMeans(dat[,harsh_vars], na.rm=T)
dat$pol_index <- rowMeans(dat[,c(auto_vars, harsh_vars)], na.rm=T)



#####
## perceived severity of crime
#####

## replace NAs
dat <- replace_NA(dat, 'crime_bad', -99)

## standardize
dat$crime_bad_st <- st_out(dat$crime_bad)



##########
## CONTROLS
##########


#####
## demographics
#####

setnames(dat, colnames(dat), gsub('demog_page.', '', colnames(dat)))
setnames(dat, colnames(dat), gsub('script_trauma.', '', colnames(dat)))
setnames(dat, colnames(dat), gsub('script_groups.', '', colnames(dat)))

## gender
dat$female <- ifelse(dat$select_gender_s=="mujere", 1, 0)


## party supports
dat$party <- gsub("somewhat_|very_", "", dat$party_page.party_any)
dat$party_close <- ifelse(grepl("very", dat$party_page.party_any), 2,
                          ifelse(grepl("somewhat", dat$party_page.party_any), 1,
                                 ifelse(grepl("none", dat$party_page.party_any), 0, NA)))


## vengeance scale XX check which need to be reverse coded
setnames(dat, colnames(dat), gsub('veng_table.', '', colnames(dat)))
dat <- replace_NA(dat, paste0('veng',seq(1,5,1)), -99)
dat$veng5 <- dat$veng5*-1 # reverse code 5th item
dat$veng_index <- st(rowMeans(dat[,paste0('veng',seq(1,5,1))], na.rm=T))
fit <- factanal(na.omit(dat[,paste0('veng',seq(1,5,1))]), 1, 'varimax', scores ='regression')
dat$veng_pc[complete.cases(dat[,paste0('veng',seq(1,5,1))])] <- st(fit$scores[,1])


## self-efficacy
setnames(dat, colnames(dat), gsub('se_table.', '', colnames(dat)))
dat <- replace_NA(dat, paste0('se',seq(1,5,1)), -99)
dat$se_index <- st(rowMeans(dat[,paste0('se',seq(1,5,1))], na.rm=T))
fit <- factanal(na.omit(dat[,paste0('se',seq(1,5,1))]), 2, 'varimax', scores ='regression')
dat$se_pc[complete.cases(dat[,paste0('se',seq(1,5,1))])] <- st(fit$scores[,1])


## married
dat$married <- ifelse(dat$marital=='married', 1, 
                          ifelse(dat$marital=="-99", NA, 0))
dat <- replace_NA(dat, 'marital', -99)


## employment
dat$employed_hh <- ifelse(grepl("salaried", dat$employment_hh), 1, 
                          ifelse(dat$employment_hh=="-99", NA, 0))
dat <- replace_NA(dat, 'employment_hh', -99)


## assets index
dat$table_assets.assets_options=NULL
assets_list <- c(grep('table_assets', colnames(dat), value = T))
dat <- replace_NA(dat, assets_list, c(-98, -99))
fit <- factanal(na.omit(dat[,c(assets_list)]), 1, 'varimax', scores ='regression')
dat$assets_fac[complete.cases(dat[,c(assets_list)])] <- st(fit$scores[,1])
dat$assets_index <- st(rowSums(dat[,assets_list], na.rm = T))
fit <- factanal(na.omit(dat[,assets_list]), 1, 'varimax', scores ='regression')
dat$assets_pc[complete.cases(dat[,assets_list])] <- st(fit$scores[,1])


## home ownership
dat$home_owner <- ifelse(dat$house=='0', 0, 
                         ifelse(dat$house=='-99' | dat$house=="", NA, 1))


## education
dat <- replace_NA(dat, 'education', -99)


## trust in the state

dat <- replace_NA(dat, c('trust_pol', 'trust_courts'), -99)
dat$trust_pol_st <- st(dat$trust_pol)
dat$trust_courts_st <- st(dat$trust_courts)
dat$trust_state_idx <- rowMeans(dat[,c('trust_pol_st', 'trust_courts_st')], na.rm=T)


## opinions of army and police

dat$opin_pol_legal <- ifelse(dat$auth_1e=="police",
                             ifelse(dat$auth1_opin.auth1_q1e=='Act according to the law or legally?', dat$auth1_opin.auth1_q1,
                                    ifelse(dat$auth1_opin.auth1_q2e=='Act according to the law or legally?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                             ifelse(dat$auth_2e=="police",
                                    ifelse(dat$auth2_opin.auth2_q1e=='Act according to the law or legally?', dat$auth2_opin.auth2_q1,
                                           ifelse(dat$auth2_opin.auth2_q2e=='Act according to the law or legally?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                    ifelse(dat$auth3_opin.auth3_q1e=='Act according to the law or legally?', dat$auth3_opin.auth3_q1,
                                           ifelse(dat$auth3_opin.auth3_q2e=='Act according to the law or legally?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_army_legal <- ifelse(dat$auth_1e=="army",
                             ifelse(dat$auth1_opin.auth1_q1e=='Act according to the law or legally?', dat$auth1_opin.auth1_q1,
                                    ifelse(dat$auth1_opin.auth1_q2e=='Act according to the law or legally?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                             ifelse(dat$auth_2e=="army",
                                    ifelse(dat$auth2_opin.auth2_q1e=='Act according to the law or legally?', dat$auth2_opin.auth2_q1,
                                           ifelse(dat$auth2_opin.auth2_q2e=='Act according to the law or legally?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                    ifelse(dat$auth3_opin.auth3_q1e=='Act according to the law or legally?', dat$auth3_opin.auth3_q1,
                                           ifelse(dat$auth3_opin.auth3_q2e=='Act according to the law or legally?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_auto_legal <- ifelse(dat$auth_1e=="autodefensas",
                              ifelse(dat$auth1_opin.auth1_q1e=='Act according to the law or legally?', dat$auth1_opin.auth1_q1,
                                     ifelse(dat$auth1_opin.auth1_q2e=='Act according to the law or legally?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                              ifelse(dat$auth_2e=="autodefensas",
                                     ifelse(dat$auth2_opin.auth2_q1e=='Act according to the law or legally?', dat$auth2_opin.auth2_q1,
                                            ifelse(dat$auth2_opin.auth2_q2e=='Act according to the law or legally?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                     ifelse(dat$auth3_opin.auth3_q1e=='Act according to the law or legally?', dat$auth3_opin.auth3_q1,
                                            ifelse(dat$auth3_opin.auth3_q2e=='Act according to the law or legally?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))

dat$opin_pol_prev <- ifelse(dat$auth_1e=="police",
                             ifelse(dat$auth1_opin.auth1_q1e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q1,
                                    ifelse(dat$auth1_opin.auth1_q2e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                             ifelse(dat$auth_2e=="police",
                                    ifelse(dat$auth2_opin.auth2_q1e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q1,
                                           ifelse(dat$auth2_opin.auth2_q2e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                    ifelse(dat$auth3_opin.auth3_q1e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q1,
                                           ifelse(dat$auth3_opin.auth3_q2e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_army_prev <- ifelse(dat$auth_1e=="army",
                              ifelse(dat$auth1_opin.auth1_q1e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q1,
                                     ifelse(dat$auth1_opin.auth1_q2e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                              ifelse(dat$auth_2e=="army",
                                     ifelse(dat$auth2_opin.auth2_q1e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q1,
                                            ifelse(dat$auth2_opin.auth2_q2e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                     ifelse(dat$auth3_opin.auth3_q1e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q1,
                                            ifelse(dat$auth3_opin.auth3_q2e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_auto_prev <- ifelse(dat$auth_1e=="autodefensas",
                              ifelse(dat$auth1_opin.auth1_q1e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q1,
                                     ifelse(dat$auth1_opin.auth1_q2e=='Effectively reduce violence and crime?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                              ifelse(dat$auth_2e=="autodefensas",
                                     ifelse(dat$auth2_opin.auth2_q1e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q1,
                                            ifelse(dat$auth2_opin.auth2_q2e=='Effectively reduce violence and crime?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                     ifelse(dat$auth3_opin.auth3_q1e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q1,
                                            ifelse(dat$auth3_opin.auth3_q2e=='Effectively reduce violence and crime?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))

dat$opin_pol_account <- ifelse(dat$auth_1e=="police",
                            ifelse(dat$auth1_opin.auth1_q1e=='Act according to the will of the people?', dat$auth1_opin.auth1_q1,
                                   ifelse(dat$auth1_opin.auth1_q2e=='Act according to the will of the people?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                            ifelse(dat$auth_2e=="police",
                                   ifelse(dat$auth2_opin.auth2_q1e=='Act according to the will of the people?', dat$auth2_opin.auth2_q1,
                                          ifelse(dat$auth2_opin.auth2_q2e=='Act according to the will of the people?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                   ifelse(dat$auth3_opin.auth3_q1e=='Act according to the will of the people?', dat$auth3_opin.auth3_q1,
                                          ifelse(dat$auth3_opin.auth3_q2e=='Act according to the will of the people?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_army_account <- ifelse(dat$auth_1e=="army",
                             ifelse(dat$auth1_opin.auth1_q1e=='Act according to the will of the people?', dat$auth1_opin.auth1_q1,
                                    ifelse(dat$auth1_opin.auth1_q2e=='Act according to the will of the people?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                             ifelse(dat$auth_2e=="army",
                                    ifelse(dat$auth2_opin.auth2_q1e=='Act according to the will of the people?', dat$auth2_opin.auth2_q1,
                                           ifelse(dat$auth2_opin.auth2_q2e=='Act according to the will of the people?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                    ifelse(dat$auth3_opin.auth3_q1e=='Act according to the will of the people?', dat$auth3_opin.auth3_q1,
                                           ifelse(dat$auth3_opin.auth3_q2e=='Act according to the will of the people?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))
dat$opin_auto_account <- ifelse(dat$auth_1e=="autodefensas",
                             ifelse(dat$auth1_opin.auth1_q1e=='Act according to the will of the people?', dat$auth1_opin.auth1_q1,
                                    ifelse(dat$auth1_opin.auth1_q2e=='Act according to the will of the people?', dat$auth1_opin.auth1_q2, dat$auth1_opin.auth1_q3)),
                             ifelse(dat$auth_2e=="autodefensas",
                                    ifelse(dat$auth2_opin.auth2_q1e=='Act according to the will of the people?', dat$auth2_opin.auth2_q1,
                                           ifelse(dat$auth2_opin.auth2_q2e=='Act according to the will of the people?', dat$auth2_opin.auth2_q2, dat$auth2_opin.auth2_q3)),
                                    ifelse(dat$auth3_opin.auth3_q1e=='Act according to the will of the people?', dat$auth3_opin.auth3_q1,
                                           ifelse(dat$auth3_opin.auth3_q2e=='Act according to the will of the people?', dat$auth3_opin.auth3_q2, dat$auth3_opin.auth3_q3))))


dat <- replace_NA(dat, c('opin_pol_legal', 'opin_army_legal', 'opin_auto_legal',
                         'opin_pol_prev', 'opin_army_prev', 'opin_auto_prev',
                         'opin_pol_account', 'opin_army_account', 'opin_auto_account'), -99)
dat$opin_pol_legal_st <- st(dat$opin_pol_legal)
dat$opin_army_legal_st <- st(dat$opin_army_legal)
dat$opin_pol_prev_st <- st(dat$opin_pol_prev)
dat$opin_army_prev_st <- st(dat$opin_army_prev)
dat$opin_pol_account_st <- st(dat$opin_pol_account)
dat$opin_army_account_st <- st(dat$opin_army_account)


dat$opin_state_legal <- rowMeans(dat[,c('opin_pol_legal_st', 'opin_army_legal_st')], na.rm=T)
dat$opin_state_prev <- rowMeans(dat[,c('opin_pol_prev_st', 'opin_army_prev_st')], na.rm=T)
dat$opin_state_account <- rowMeans(dat[,c('opin_pol_account_st', 'opin_army_account_st')], na.rm=T)
dat$opin_state_all <- rowMeans(dat[,c('opin_pol_legal_st', 'opin_army_legal_st', 
                                      'opin_pol_prev_st', 'opin_army_prev_st',
                                      'opin_pol_account_st', 'opin_army_account_st')], na.rm=T)


#####
## pre treatment emotions
#####

## fear

dat$fear_pre <- NA
dat$fear_pre <- ifelse(dat$panas_table.panas1_e=='Afraid', dat$panas_table.panas1,
                        ifelse(dat$panas_table.panas2_e=='Afraid', dat$panas_table.panas2,
                               ifelse(dat$panas_table.panas3_e=='Afraid', dat$panas_table.panas3,
                                      ifelse(dat$panas_table.panas4_e=='Afraid', dat$panas_table.panas4,
                                             ifelse(dat$panas_table.panas5_e=='Afraid', dat$panas_table.panas5,
                                                    ifelse(dat$panas_table.panas6_e=='Afraid', dat$panas_table.panas6,
                                                           ifelse(dat$panas_table.panas7_e=='Afraid', dat$panas_table.panas7,
                                                                  ifelse(dat$panas_table.panas8_e=='Afraid', dat$panas_table.panas8,
                                                           dat$fear_pre))))))))

dat <- replace_NA(dat, 'fear_pre', -99)
dat$fear_pre_st <- st(dat$fear_pre)


## nervous

dat$nervous_pre <- NA
dat$nervous_pre <- ifelse(dat$panas_table.panas1_e=='Nervous', dat$panas_table.panas1,
                       ifelse(dat$panas_table.panas2_e=='Nervous', dat$panas_table.panas2,
                              ifelse(dat$panas_table.panas3_e=='Nervous', dat$panas_table.panas3,
                                     ifelse(dat$panas_table.panas4_e=='Nervous', dat$panas_table.panas4,
                                            ifelse(dat$panas_table.panas5_e=='Nervous', dat$panas_table.panas5,
                                                   ifelse(dat$panas_table.panas6_e=='Nervous', dat$panas_table.panas6,
                                                          ifelse(dat$panas_table.panas7_e=='Nervous', dat$panas_table.panas7,
                                                                 ifelse(dat$panas_table.panas8_e=='Nervous', dat$panas_table.panas8,
                                                          dat$nervous_pre))))))))
dat <- replace_NA(dat, 'nervous_pre', -99)
dat$nervous_pre_st <- st(dat$nervous_pre)

dat$fear_pre_index <- rowMeans(dat[,c('fear_pre_st', 'nervous_pre_st')], na.rm=T)


## anger

dat$anger_pre <- NA
dat$anger_pre <- ifelse(dat$panas_table.panas1_e=='Angry', dat$panas_table.panas1,
                       ifelse(dat$panas_table.panas2_e=='Angry', dat$panas_table.panas2,
                              ifelse(dat$panas_table.panas3_e=='Angry', dat$panas_table.panas3,
                                     ifelse(dat$panas_table.panas4_e=='Angry', dat$panas_table.panas4,
                                            ifelse(dat$panas_table.panas5_e=='Angry', dat$panas_table.panas5,
                                                   ifelse(dat$panas_table.panas6_e=='Angry', dat$panas_table.panas6, 
                                                          ifelse(dat$panas_table.panas7_e=='Angry', dat$panas_table.panas7, 
                                                                 ifelse(dat$panas_table.panas8_e=='Angry', dat$panas_table.panas8, 
                                                          dat$anger_pre))))))))
dat <- replace_NA(dat, 'anger_pre', -99)
dat$anger_pre_st <- st(dat$anger_pre)

## indignant

dat$indignant_pre <- NA
dat$indignant_pre <- ifelse(dat$panas_table.panas1_e=='Indignant', dat$panas_table.panas1,
                        ifelse(dat$panas_table.panas2_e=='Indignant', dat$panas_table.panas2,
                               ifelse(dat$panas_table.panas3_e=='Indignant', dat$panas_table.panas3,
                                      ifelse(dat$panas_table.panas4_e=='Indignant', dat$panas_table.panas4,
                                             ifelse(dat$panas_table.panas5_e=='Indignant', dat$panas_table.panas5,
                                                    ifelse(dat$panas_table.panas6_e=='Indignant', dat$panas_table.panas6, 
                                                           ifelse(dat$panas_table.panas7_e=='Indignant', dat$panas_table.panas7, 
                                                                  ifelse(dat$panas_table.panas8_e=='Indignant', dat$panas_table.panas8, 
                                                                         dat$indignant_pre))))))))
dat <- replace_NA(dat, 'indignant_pre', -99)
dat$indignant_pre_st <- st(dat$indignant_pre)

dat$anger_pre_index <- rowMeans(dat[,c('anger_pre_st', 'indignant_pre_st')], na.rm=T)


## sadness

dat$sad_pre <- NA
dat$sad_pre <- ifelse(dat$panas_table.panas1_e=='Sad', dat$panas_table.panas1,
                        ifelse(dat$panas_table.panas2_e=='Sad', dat$panas_table.panas2,
                               ifelse(dat$panas_table.panas3_e=='Sad', dat$panas_table.panas3,
                                      ifelse(dat$panas_table.panas4_e=='Sad', dat$panas_table.panas4,
                                             ifelse(dat$panas_table.panas5_e=='Sad', dat$panas_table.panas5,
                                                    ifelse(dat$panas_table.panas6_e=='Sad', dat$panas_table.panas6, 
                                                           ifelse(dat$panas_table.panas7_e=='Sad', dat$panas_table.panas7, 
                                                                  ifelse(dat$panas_table.panas8_e=='Sad', dat$panas_table.panas9, 
                                                                         dat$sad_pre))))))))
dat <- replace_NA(dat, 'sad_pre', -99)
dat$sad_pre_st <- st(dat$sad_pre)

## dejected

dat$dejected_pre <- NA
dat$dejected_pre <- ifelse(dat$panas_table.panas1_e=='Dejected', dat$panas_table.panas1,
                       ifelse(dat$panas_table.panas2_e=='Dejected', dat$panas_table.panas2,
                              ifelse(dat$panas_table.panas3_e=='Dejected', dat$panas_table.panas3,
                                     ifelse(dat$panas_table.panas4_e=='Dejected', dat$panas_table.panas4,
                                            ifelse(dat$panas_table.panas5_e=='Dejected', dat$panas_table.panas5,
                                                   ifelse(dat$panas_table.panas6_e=='Dejected', dat$panas_table.panas6, 
                                                          ifelse(dat$panas_table.panas7_e=='Dejected', dat$panas_table.panas7, 
                                                                 ifelse(dat$panas_table.panas8_e=='Dejected', dat$panas_table.panas8, 
                                                                        dat$dejected_pre))))))))

dat <- replace_NA(dat, 'dejected_pre', -99)
dat$dejected_pre_st <- st(dat$dejected_pre)

dat$sad_pre_index <- rowMeans(dat[,c('sad_pre_st', 'dejected_pre_st')], na.rm=T)


## cheerful

dat$cheerful_pre <- NA
dat$cheerful_pre <- ifelse(dat$panas_table.panas1_e=='Cheerful', dat$panas_table.panas1,
                        ifelse(dat$panas_table.panas2_e=='Cheerful', dat$panas_table.panas2,
                               ifelse(dat$panas_table.panas3_e=='Cheerful', dat$panas_table.panas3,
                                      ifelse(dat$panas_table.panas4_e=='Cheerful', dat$panas_table.panas4,
                                             ifelse(dat$panas_table.panas5_e=='Cheerful', dat$panas_table.panas5,
                                                    ifelse(dat$panas_table.panas6_e=='Cheerful', dat$panas_table.panas6, 
                                                           ifelse(dat$panas_table.panas7_e=='Cheerful', dat$panas_table.panas7, 
                                                                  ifelse(dat$panas_table.panas8_e=='Cheerful', dat$panas_table.panas8, 
                                                                         dat$cheerful_pre))))))))
dat <- replace_NA(dat, 'cheerful_pre', -99)
dat$cheerful_pre_st <- st(dat$cheerful_pre)


## happiness

dat$happy_pre <- NA
dat$happy_pre <- ifelse(dat$panas_table.panas1_e=='Happy', dat$panas_table.panas1,
                      ifelse(dat$panas_table.panas2_e=='Happy', dat$panas_table.panas2,
                             ifelse(dat$panas_table.panas3_e=='Happy', dat$panas_table.panas3,
                                    ifelse(dat$panas_table.panas4_e=='Happy', dat$panas_table.panas4,
                                           ifelse(dat$panas_table.panas5_e=='Happy', dat$panas_table.panas5,
                                                  ifelse(dat$panas_table.panas6_e=='Happy', dat$panas_table.panas6, 
                                                         ifelse(dat$panas_table.panas7_e=='Happy', dat$panas_table.panas7, 
                                                                ifelse(dat$panas_table.panas8_e=='Happy', dat$panas_table.panas8, 
                                                                       dat$happy_pre))))))))

dat <- replace_NA(dat, 'happy_pre', -99)
dat$happy_pre_st <- st(dat$happy_pre)

dat$happy_pre_index <- rowMeans(dat[,c('happy_pre_st', 'cheerful_pre_st')], na.rm=T)





#####
## past exposure to violence - indirect
#####

setnames(dat, gsub("script_insec.", "", colnames(dat)))
dat$insec_lab=NULL
insec_list <- grep("insec_", colnames(dat), value = T)

dat <- replace_NA(dat, insec_list, c(-98,-99))

dat$insec_index <- st(rowMeans(dat[,insec_list], na.rm=T))

insec_exp_list <- c('insec_extortion', 'insec_abduction', 'insec_protection', 'insec_weapon', 
                    'insec_assault')
dat$insec_exp_index <- st(rowMeans(dat[,insec_exp_list], na.rm=T))

insec_wit_list <- c('insec_murder', 'insec_body', 'insec_blockade', 'insec_banner', 
                    'insec_lynching')
dat$insec_wit_index <- st(rowMeans(dat[,insec_wit_list], na.rm=T))



#####
## past exposure to violence - direct
#####

setnames(dat, gsub("script_trauma.", "", colnames(dat)))
dat$trauma_lab=NULL
trauma_list <- grep("trauma_", colnames(dat), value = T)

dat <- replace_NA(dat, trauma_list, c(-98,-99))

dat$trauma_index <- st(rowMeans(dat[,trauma_list], na.rm=T))


#####
## armed groups presence
#####

dat$groups.lab=NULL
groups_list <- grep("groups.", colnames(dat), value = T)
dat <- replace_NA(dat, groups_list, c(-98,-99))


#####
## blame
#####

setnames(dat, c('table_blame.blame_narcos', 'table_blame.blame_pol', 
                'table_blame.blame_auto', 'table_blame.blame_fedpol',
                'table_blame.blame_locpol', 'table_blame.blame_army'),
         c('blame_1', 'blame_2', 'blame_3', 'blame_4', 'blame_5', 'blame_6'))

dat$blame_narcos <- ifelse(dat$blame1_e=="The narcos?", dat$blame_1,
                           ifelse(dat$blame2_e=="The narcos?", dat$blame_2,
                                  ifelse(dat$blame3_e=="The narcos?", dat$blame_3,
                                         ifelse(dat$blame4_e=="The narcos?", dat$blame_4,
                                                ifelse(dat$blame5_e=="The narcos?", dat$blame_5,
                                                       ifelse(dat$blame6_e=="The narcos?", dat$blame_6, 
                                                              NA))))))
dat$blame_pol <- ifelse(dat$blame1_e=="The politicians?", dat$blame_1,
                        ifelse(dat$blame2_e=="The politicians?", dat$blame_2,
                               ifelse(dat$blame3_e=="The politicians?", dat$blame_3,
                                      ifelse(dat$blame4_e=="The politicians?", dat$blame_4,
                                             ifelse(dat$blame5_e=="The politicians?", dat$blame_5,
                                                    ifelse(dat$blame6_e=="The politicians?", dat$blame_6, 
                                                           NA))))))
dat$blame_auto <- ifelse(dat$blame1_e=="The autodefensas?", dat$blame_1,
                         ifelse(dat$blame2_e=="The autodefensas?", dat$blame_2,
                                ifelse(dat$blame3_e=="The autodefensas?", dat$blame_3,
                                       ifelse(dat$blame4_e=="The autodefensas?", dat$blame_4,
                                              ifelse(dat$blame5_e=="The autodefensas?", dat$blame_5,
                                                     ifelse(dat$blame6_e=="The autodefensas?", dat$blame_6, 
                                                            NA))))))
dat$blame_fedpol <- ifelse(dat$blame1_e=="The federal police?", dat$blame_1,
                           ifelse(dat$blame2_e=="The federal police?", dat$blame_2,
                                  ifelse(dat$blame3_e=="The federal police?", dat$blame_3,
                                         ifelse(dat$blame4_e=="The federal police?", dat$blame_4,
                                                ifelse(dat$blame5_e=="The federal police?", dat$blame_5,
                                                       ifelse(dat$blame6_e=="The federal police?", dat$blame_6, 
                                                              NA))))))
dat$blame_locpol <- ifelse(dat$blame1_e=="The local police?", dat$blame_1,
                           ifelse(dat$blame2_e=="The local police?", dat$blame_2,
                                  ifelse(dat$blame3_e=="The local police?", dat$blame_3,
                                         ifelse(dat$blame4_e=="The local police?", dat$blame_4,
                                                ifelse(dat$blame5_e=="The local police?", dat$blame_5,
                                                       ifelse(dat$blame6_e=="The local police?", dat$blame_6, 
                                                              NA))))))
dat$blame_army <- ifelse(dat$blame1_e=="The army?", dat$blame_1,
                         ifelse(dat$blame2_e=="The army?", dat$blame_2,
                                ifelse(dat$blame3_e=="The army?", dat$blame_3,
                                       ifelse(dat$blame4_e=="The army?", dat$blame_4,
                                              ifelse(dat$blame5_e=="The army?", dat$blame_5,
                                                     ifelse(dat$blame6_e=="The army?", dat$blame_6, 
                                                            NA))))))

## replace NAs
dat <- replace_NA(dat, c('blame_army', 'blame_fedpol', 'blame_locpol', 
                         'blame_pol', 'blame_auto', 'blame_narcos'),
                  -99)


## make standardized measures
dat$blame_army_st <- st(dat$blame_army)
dat$blame_fedpol_st <- st(dat$blame_fedpol)
dat$blame_locpol_st <- st(dat$blame_locpol)
dat$blame_pol_st <- st(dat$blame_pol)
dat$blame_auto_st <- st(dat$blame_auto)
dat$blame_narcos_st <- st(dat$blame_narcos)


## make indices
dat$blame_all <- rowMeans(dat[,c('blame_army', 'blame_fedpol', 'blame_locpol', 
                                 'blame_pol', 'blame_auto', 'blame_narcos')], na.rm=T)

dat$blame_all_st <- rowMeans(dat[,c('blame_army_st', 'blame_fedpol_st', 'blame_locpol_st', 
                                    'blame_pol_st', 'blame_auto_st', 'blame_narcos_st')], na.rm=T)



#####
## punishment
#####

setnames(dat, c('table_pun.pun_narcos', 'table_pun.pun_pol', 
                'table_pun.pun_auto', 'table_pun.pun_fedpol',
                'table_pun.pun_locpol', 'table_pun.pun_army'),
         c('pun_1', 'pun_2', 'pun_3', 'pun_4', 'pun_5', 'pun_6'))

dat$pun_narcos <- ifelse(dat$pun1_e=="The narcos?", dat$pun_1,
                         ifelse(dat$pun2_e=="The narcos?", dat$pun_2,
                                ifelse(dat$pun3_e=="The narcos?", dat$pun_3,
                                       ifelse(dat$pun4_e=="The narcos?", dat$pun_4,
                                              ifelse(dat$pun5_e=="The narcos?", dat$pun_5,
                                                     ifelse(dat$pun6_e=="The narcos?", dat$pun_6, 
                                                            NA))))))
dat$pun_pol <- ifelse(dat$pun1_e=="The politicians?", dat$pun_1,
                      ifelse(dat$pun2_e=="The politicians?", dat$pun_2,
                             ifelse(dat$pun3_e=="The politicians?", dat$pun_3,
                                    ifelse(dat$pun4_e=="The politicians?", dat$pun_4,
                                           ifelse(dat$pun5_e=="The politicians?", dat$pun_5,
                                                  ifelse(dat$pun6_e=="The politicians?", dat$pun_6, 
                                                         NA))))))
dat$pun_auto <- ifelse(dat$pun1_e=="The autodefensas?", dat$pun_1,
                       ifelse(dat$pun2_e=="The autodefensas?", dat$pun_2,
                              ifelse(dat$pun3_e=="The autodefensas?", dat$pun_3,
                                     ifelse(dat$pun4_e=="The autodefensas?", dat$pun_4,
                                            ifelse(dat$pun5_e=="The autodefensas?", dat$pun_5,
                                                   ifelse(dat$pun6_e=="The autodefensas?", dat$pun_6, 
                                                          NA))))))
dat$pun_fedpol <- ifelse(dat$pun1_e=="The federal police?", dat$pun_1,
                         ifelse(dat$pun2_e=="The federal police?", dat$pun_2,
                                ifelse(dat$pun3_e=="The federal police?", dat$pun_3,
                                       ifelse(dat$pun4_e=="The federal police?", dat$pun_4,
                                              ifelse(dat$pun5_e=="The federal police?", dat$pun_5,
                                                     ifelse(dat$pun6_e=="The federal police?", dat$pun_6, 
                                                            NA))))))
dat$pun_locpol <- ifelse(dat$pun1_e=="The local police?", dat$pun_1,
                         ifelse(dat$pun2_e=="The local police?", dat$pun_2,
                                ifelse(dat$pun3_e=="The local police?", dat$pun_3,
                                       ifelse(dat$pun4_e=="The local police?", dat$pun_4,
                                              ifelse(dat$pun5_e=="The local police?", dat$pun_5,
                                                     ifelse(dat$pun6_e=="The local police?", dat$pun_6, 
                                                            NA))))))
dat$pun_army <- ifelse(dat$pun1_e=="The army?", dat$pun_1,
                       ifelse(dat$pun2_e=="The army?", dat$pun_2,
                              ifelse(dat$pun3_e=="The army?", dat$pun_3,
                                     ifelse(dat$pun4_e=="The army?", dat$pun_4,
                                            ifelse(dat$pun5_e=="The army?", dat$pun_5,
                                                   ifelse(dat$pun6_e=="The army?", dat$pun_6, 
                                                          NA))))))

## replace NAs
dat <- replace_NA(dat, c('pun_army', 'pun_fedpol', 'pun_locpol', 
                         'pun_pol', 'pun_auto', 'pun_narcos'),
                  -99)


## make standardized measures
dat$pun_army_st <- st(dat$pun_army)
dat$pun_fedpol_st <- st(dat$pun_fedpol)
dat$pun_locpol_st <- st(dat$pun_locpol)
dat$pun_pol_st <- st(dat$pun_pol)
dat$pun_auto_st <- st(dat$pun_auto)
dat$pun_narcos_st <- st(dat$pun_narcos)


## make indices
dat$pun_all <- rowMeans(dat[,c('pun_army', 'pun_fedpol', 'pun_locpol', 
                               'pun_pol', 'pun_auto', 'pun_narcos')], na.rm=T)
dat$pun_all_st <- rowMeans(dat[,c('pun_army_st', 'pun_fedpol_st', 'pun_locpol_st', 
                                  'pun_pol_st', 'pun_auto_st', 'pun_narcos_st')], na.rm=T)


## community 

table(dat$community_other)
dat$community <- ifelse(dat$state=="jalisco", as.character(dat$community_jal),
                        ifelse(dat$state=="michoacan", as.character(dat$community_mich),
                               ifelse(dat$state=="nayarit", as.character(dat$community_naya),
                                      as.character(dat$community_coli))))

dat$psu <- paste0(dat$community, "_", dat$section)


## clean community (some were manually entered wrong)

dat$psu_old <- dat$psu

table(dat$psu[dat$state=='michoacan'], dat$date[dat$state=='michoacan'])

dat$psu <- ifelse(dat$psu %in% c("APATZINGAN_2364", "APATZINGAN_2426"), "APATZINGAN_2664", dat$psu)
dat$psu <- ifelse(dat$psu=="HIDALGO_840", "HIDALGO_480", dat$psu)
dat$psu <- ifelse(dat$psu=="LA PIEDAD_153", "LA PIEDAD_1531", dat$psu)
dat$psu <- ifelse(dat$psu=="MORELIA_11", "MORELIA_1181", dat$psu)
dat$psu <- ifelse(dat$psu=="PUREPERO_1", "PUREPERO_1594", dat$psu)
dat$psu <- ifelse(dat$psu=="TLAZAZALCA_95", "TLAZAZALCA_2050", dat$psu)
dat$psu <- ifelse(dat$psu=="TING\xa0INDIN_2088", "TING\xa0INDIN_2008", dat$psu)
dat$psu <- ifelse(dat$psu=="CHARO_436", "CHARO_346", dat$psu)
dat$psu <- ifelse(dat$psu=="CHAVINDA_635", "CHAVINDA_365", dat$psu)
dat$psu <- ifelse(dat$psu %in% c("PARACUARO_2126", "PARACUARO_2674", "PATZCUARO_2671"),
                  "PARACUARO_2671", dat$psu)
dat$psu <- ifelse(dat$psu=="PANINDICUARO_1626", 'PURUANDIRO_1626', dat$psu)
dat$psu <- ifelse(dat$psu=="PATZCUARO_1419", "PATZCUARO_1490", dat$psu)
dat$psu <- ifelse(dat$psu=="PATZCUARO_1594", "PARACUARO_1594", dat$psu)
dat$psu <- ifelse(dat$psu=="MUGICA_578", "MUGICA_1299", dat$psu) ## both of these are in our sample
dat$psu <- ifelse(dat$psu=="TUZANTLA_511", "TUZANTLA_2133", dat$psu) ## maybe both in sample
dat$psu <- ifelse(dat$psu=="HIDALGO_844", "HIDALGO_488", dat$psu) ## maybe both in sample
dat$psu <- ifelse(dat$psu=="COJUMATLAN DE REGULES_511", "HIDALGO_511", dat$psu) 
dat$psu <- ifelse(dat$psu=="HIDALGO_2133", "TUZANTLA_2133", dat$psu) 
dat$psu <- ifelse(dat$psu=="TONALA_2008", "TING\xa0INDIN_2008", dat$psu) 
dat$psu <- ifelse(dat$psu=="JIQUILPAN_2008", "TING\xa0INDIN_2008", dat$psu) 
dat$psu <- ifelse(dat$psu=="APATZINGAN_1490", "PATZCUARO_1490", dat$psu) 


table(dat$psu[dat$state=='jalisco'], dat$date[dat$state=='jalisco'])

dat$psu <- ifelse(dat$psu %in% c("ENCARNACION DE DIAZ_124", "ENCARNACION DE DIAZ_50"), "ENCARNACION DE DIAZ_501", dat$psu)
dat$psu <- ifelse(dat$psu=="GUADALAJARA_9015", "GUADALAJARA_915", dat$psu)
dat$psu <- ifelse(dat$psu=="LAGOS DE MORENO_501", "LAGOS DE MORENO_1714", dat$psu)
dat$psu <- ifelse(dat$psu=="OCOTLAN_1883", "OCOTLAN_1873", dat$psu)
dat$psu <- ifelse(dat$psu=="OCOTLAN_1", "OCOTLAN_1854", dat$psu)
dat$psu <- ifelse(dat$psu=="ZAPOPAN_2349", "ZAPOPAN_2943", dat$psu)
dat$psu <- ifelse(dat$psu=="PUERTO VALLARTA_1196", "PUERTO VALLARTA_1996", dat$psu)
dat$psu <- ifelse(dat$psu=="ZAPOPAN_1227", "ZAPOPAN_2915", dat$psu)
dat$psu <- ifelse(dat$psu=="AHUALULCO DE MERCADO_2585", "SAN PEDRO TLAQUEPAQUE_2585", dat$psu)
dat$psu <- ifelse(dat$psu=="GUADALAJARA_3183", "GUADALAJARA_1383", dat$psu)


table(dat$psu[dat$state=='nayarit'], dat$date[dat$state=='nayarit'])

dat$psu <- ifelse(dat$psu=="TEPIC_734", "TEPIC_732", dat$psu)


table(dat$psu[dat$state=='colima'], dat$date[dat$state=='colima'])

length(unique(dat$psu))
mean(table(dat$psu))
hist(table(dat$psu))


## make corrected section #
dat$section_old <- dat$section
dat$section <- sapply(strsplit(dat$psu, split = "_", fixed = T), function(x) x[2])
dat$psu[is.na(dat$section)]
dat$section[dat$psu=="TLAJOMULCO DE ZU\xe3IGA_3415"] <- '3415'
dat$section[dat$psu=="TING\xa0INDIN_2008"] <- '2008'
dat$section[dat$psu=="TLAJOMULCO DE ZU\xe3IGA_3432"] <- '3432'
dat$section[dat$psu=="TLAJOMULCO DE ZU\xe3IGA_2468"] <- '2468'
dat$section[dat$psu=="BRISE\xe3AS_185"] <- '185'


## state dummies
dat$mich <- ifelse(dat$state=="michoacan", 1, 0)
dat$coli <- ifelse(dat$state=="colima", 1, 0)
dat$jali <- ifelse(dat$state=="jalisco", 1, 0)
dat$naya <- ifelse(dat$state=="nayarit", 1, 0)


## binary versions of group exposure
dat$groups_army_bin <- ifelse(dat$groups.army<=1, 0, ifelse(dat$groups.army>1, 1, NA))
dat$groups_narcos_bin <- ifelse(dat$groups.narcos<=1, 0, ifelse(dat$groups.narcos>1, 1, NA))
dat$groups_auto_bin <- ifelse(dat$groups.auto<=1, 0, ifelse(dat$groups.auto>1, 1, NA))
dat$groups_police_bin <- ifelse(dat$groups.police<=1, 0, ifelse(dat$groups.police>1, 1, NA))


##### 
## merge in samples
#####

samm1 <- read.xls("02_Data/01_Samples/mich_sample1.xlsx")
samm1$sample <- 1
samm2 <- read.xls("02_Data/01_Samples/mich_sample2.xlsx")
samm2$sample <- 2
samm3 <- read.xls("02_Data/01_Samples/mich_sample3.xlsx")
samm3$sample <- 3
samm4 <- read.xls("02_Data/01_Samples/mich_sample4.xlsx")
samm4$sample <- 4
samm5 <- read.xls("02_Data/01_Samples/mich_sample5.xlsx")
samm5$sample <- 5

samw1 <- read.xls("02_Data/01_Samples/west_sample1.xlsx")
samw1$sample <- 1
samw2 <- read.xls("02_Data/01_Samples/west_sample2.xlsx")
samw2$sample <- 2
samw3 <- read.xls("02_Data/01_Samples/west_sample3.xlsx")
samw3$sample <- 3
samw4 <- read.xls("02_Data/01_Samples/west_sample4.xlsx")
samw4$sample <- 4
samw5 <- read.xls("02_Data/01_Samples/west_sample5.xlsx")
samw5$sample <- 5

sample <- smartbind(samm1, samm2, samm3, samm4, samm5,
                    samw1, samw2, samw3, samw4, samw5)
sample$psu <- paste(sample$NOMBRE_MUNICIPIO, sample$SECCION, sep = "_")
sample$psu <- gsub("BRISE\xd1AS", "BRISE\xe3AS", sample$psu, fixed = T, useBytes = T)
sample$psu <- gsub("TLAJOMULCO DE ZU\xd1IGA", "TLAJOMULCO DE ZU\xe3IGA", sample$psu, fixed = T, useBytes = T)
sample$psu <- gsub("TING\xdcINDIN", "TING\xa0INDIN", sample$psu, fixed = T, useBytes = T)

sample <- sample[order(sample$sample, sample$psu),]
sample$duplicated <- ifelse(duplicated(sample$psu)==T, 1, 0)

sample <- sample[sample$duplicated==0,]

dat <- merge(dat, sample, by = 'psu', all.x = T)


write.csv(sample, "02_Data/03_Clean/samples_clean.csv")


#####
## scenario preferences
#####

## clean conjoint prefs

dat <- replace_NA(dat, c('scen1.scen1_anger', 'scen1.scen1_fear', 'scen1.scen1_here'), -99)

dat$scen1_punishment <- as.character(dat$scen1_b.scen1_punishment)
dat$scen1_punisher_other <- tolower(gsub(" *$", "", dat$scen1_punisher_other))
dat$scen1_punishment[dat$scen1_punisher_other %in% c("la autoridad", "la ley", "la justicia",
                                                         "el gobierno", "las autoridades",
                                                         "gobierno", 'un juez', 
                                                         'las autoridades correspondientes',
                                                         'juez', 'sistema judicial', 'los jueces',
                                                         'las leyes', 'autoridades competentes',
                                                     'la aut correspondiente', 'municipio', 
                                                     'municipio de paracuaro')] <- "court"

dat$scen1_pun_extrajud <- NA
dat$scen1_pun_extrajud[dat$scen1_punishment %in% c('court', 'deathpen', 'jaillong', 'jailshort', 'none')] <- 0
dat$scen1_pun_extrajud[dat$scen1_punishment %in% c('beat', 'lynched', 'shot')] <- 1
dat$scen1_pun_extrajud[dat$scen1_punisher_other %in% c("uno mismo", "todos en conjunto", "el narco")] <- 

dat$scen1_pun_sev <- NA
dat$scen1_pun_sev[dat$scen1_punishment %in% c('none')] <- 0
dat$scen1_pun_sev[dat$scen1_punishment %in% c('beat', 'jailshort')] <- 1
dat$scen1_pun_sev[dat$scen1_punishment %in% c('jaillong')] <- 2
dat$scen1_pun_sev[dat$scen1_punishment %in% c('deathpen', 'lynched', 'shot')] <- 3

dat$scen1_prin_rank_sev <- NA
dat$scen1_prin_rank_sev[dat$scen1_e.scen1_principle=="severity"] <- 1
dat$scen1_prin_rank_sev[dat$scen1_e.scen1_principle %in% c("legality", "prevention")] <- 0

dat$scen1_prin_rank_legal <- NA
dat$scen1_prin_rank_legal[dat$scen1_e.scen1_principle=="legality"] <- 1
dat$scen1_prin_rank_legal[dat$scen1_e.scen1_principle %in% c("severity", "prevention")] <- 0

dat$scen1_prin_rank_prev <- NA
dat$scen1_prin_rank_prev[dat$scen1_e.scen1_principle=="prevention"] <- 1
dat$scen1_prin_rank_prev[dat$scen1_e.scen1_principle %in% c("severity", "legality")] <- 0

dat$scen1_prin_prev <- ifelse(dat$scen1_d.pun1_pref_1e=="The punishment prevents other crimes from being committed in the future?", dat$scen1_d.scen1_pun_pref_1,
                              ifelse(dat$scen1_d.pun1_pref_2e=="The punishment prevents other crimes from being committed in the future?", dat$scen1_d.scen1_pun_pref_2,
                                     dat$scen1_d.scen1_pun_pref_3))

dat$scen1_prin_sev <- ifelse(dat$scen1_d.pun1_pref_1e=="The perpetrator is punished as severely as the crime he committed or gets what he deserves?", dat$scen1_d.scen1_pun_pref_1,
                              ifelse(dat$scen1_d.pun1_pref_2e=="The perpetrator is punished as severely as the crime he committed or gets what he deserves?", dat$scen1_d.scen1_pun_pref_2,
                                     dat$scen1_d.scen1_pun_pref_3))

dat$scen1_prin_legal <- ifelse(dat$scen1_d.pun1_pref_1e=="The perpetrator is treated fairly under the law, meaning that rules and procedures are correctly followed?", dat$scen1_d.scen1_pun_pref_1,
                             ifelse(dat$scen1_d.pun1_pref_2e=="The perpetrator is treated fairly under the law, meaning that rules and procedures are correctly followed?", dat$scen1_d.scen1_pun_pref_2,
                                    dat$scen1_d.scen1_pun_pref_3))

dat <- replace_NA(dat, c('scen1_prin_prev', 'scen1_prin_sev', 'scen1_prin_legal'), -99)



## clean conjoint indep vars

dat$scen1_vic_inno <- ifelse(dat$vic1_e %in% c('student', 'grandmother', 'local small business owner'), 1,
                           ifelse(dat$vic1_e %in% c('soldier'), 0, -1))
dat$scen1_vio_sev <- ifelse(dat$vio1_e %in% c('killed', 'disappeared'), 1,
                          ifelse(dat$vio1_e %in% c('tortured', 'extorted for money'), 0, -1))
dat$scen1_per_gov <- ifelse(dat$per1_e %in% c('federal police officer', 'local police officer', 'soldier'), 1,
                            0)


## order factors

dat$vic1_e <- factor(dat$vic1_e, ordered = T, levels = c('narco', 'soldier',
                                                         'local small business owner', 
                                                         'student', 'grandmother'))
dat$vio1_e <- factor(dat$vio1_e, ordered = T, levels = c('robbed', 'extorted for money',
                                                         'tortured', 
                                                         'killed', 'disappeared'))
dat$per1_e <- factor(dat$per1_e, ordered = T, levels = c('narco', 'autodefensas member',
                                                         'local police officer', 
                                                         'federal police officer', 'soldier'))

## rename some conjoint vars

setnames(dat, grep("scen1.", colnames(dat), fixed = T, value = T), 
         gsub("scen1.", "", grep("scen1.", colnames(dat), fixed = T, value = T), fixed = T))



#####
## merge in sampling weights 
#####

## locality inverse propensity weights

w <- read.csv('02_Data/02_Raw/ea_weights.csv')
w$state <- tolower(gsub("MichoacÃ¡n de Ocampo", "michoacan", w$statename))

dat <- merge(dat, w, by.x = c('state', 'section'), by.y = c('state', 'SECCION'), all.x = T)


## locality propensity & gender-age proportions

w <- read.csv('02_Data/02_Raw/ag_weights.csv')
w$state <- tolower(gsub("MichoacÃ¡n de Ocampo", "michoacan", w$statename))

# dat$ag_cat <- recode(dat$age, "lo:29='1829'; 30:39='3039'; 40:49='4049'; 50:59='5059'; 60:hi='60m'")
dat$ag_cat <- cut(dat$age, breaks = c(0,30,40,50,60,120), labels = c('1829','3039','4049','5059','60m'))
foo <- ifelse(dat$female==1, 'm', 'h')
dat$ag_cat <- paste0(foo, dat$ag_cat)
table(dat$ag_cat)
w <- subset(w, select = c(state, SECCION, variable, prop_ag, w_ag))
dat <- merge(dat, w, by.x = c('state', 'section', 'ag_cat'), by.y = c('state', 'SECCION', 'variable'),
             all.x = T)


#####
## write to csv
#####

## write full dataset (with wide version of conjoint) to csv
write.csv(dat, '02_Data/03_Clean/data_main_clean.csv')

